@@ -36,9 +36,11 @@ function _heat_set_user {
     OS_PROJECT_DOMAIN_ID=$DEFAULT_DOMAIN
 }
 
-function create {
-    # run heat_integrationtests instead of tempest smoke before create
-    pushd $BASE_DEVSTACK_DIR/../tempest
+function _run_heat_api_tests {
+    local devstack_dir=$1
+
+    pushd $devstack_dir/../tempest
+    sed -i -e '/group_regex/c\group_regex=heat_tempest_plugin\\.tests\\.api\\.test_heat_api(?:\\.|_)([^_]+)' .stestr.conf
     conf_file=etc/tempest.conf
     iniset_multiline $conf_file service_available heat_plugin True
     iniset $conf_file heat_plugin username $OS_USERNAME
@@ -50,24 +52,14 @@ function create {
     iniset $conf_file heat_plugin user_domain_name $OS_USER_DOMAIN_NAME
     iniset $conf_file heat_plugin project_domain_name $OS_PROJECT_DOMAIN_NAME
     iniset $conf_file heat_plugin region $OS_REGION_NAME
-
-    # Old version of tempest is installed in grenade environment, so use
-    # .testr.conf instead of .stestr.conf
-    cat <<'EOF' >.testr.conf
-[DEFAULT]
-test_command=OS_STDOUT_CAPTURE=${OS_STDOUT_CAPTURE:-1} \
-             OS_STDERR_CAPTURE=${OS_STDERR_CAPTURE:-1} \
-             OS_TEST_TIMEOUT=${OS_TEST_TIMEOUT:-500} \
-             OS_TEST_LOCK_PATH=${OS_TEST_LOCK_PATH:-${TMPDIR:-'/tmp'}} \
-             ${PYTHON:-python} -m subunit.run discover -t ${OS_TOP_LEVEL:-./} \
-             ${OS_TEST_PATH:-./tempest/test_discover} $LISTOPT $IDOPTION
-test_id_option=--load-list $IDFILE
-test_list_option=--list
-group_regex=([^\.]*\.)*
-EOF
-
-    tempest run --regex '(test_create_update.CreateStackTest|test_create_update.UpdateStackTest)'
+    iniset $conf_file heat_plugin auth_version $OS_IDENTITY_API_VERSION
+    tox -evenv-tempest -- tempest run --regex heat_tempest_plugin.tests.api
     popd
+}
+
+function create {
+    # run heat api tests instead of tempest smoke before create
+    _run_heat_api_tests $BASE_DEVSTACK_DIR
 
     # creates a tenant for the server
     eval $(openstack project create -f shell -c id $HEAT_PROJECT)
@@ -100,6 +92,10 @@ EOF
 
 function verify {
     _heat_set_user
+    local side="$1"
+    if [[ "$side" = "post-upgrade" ]]; then
+        _run_heat_api_tests $TARGET_DEVSTACK_DIR
+    fi
     stack_name=$(resource_get heat stack_name)
     heat stack-show $stack_name
     # TODO(sirushtim): Create more granular checks for Heat.
@@ -131,7 +127,7 @@ case $1 in
         verify_noapi
         ;;
     "verify")
-        verify
+        verify $2
         ;;
     "destroy")
         destroy
