@@ -26,20 +26,23 @@ class ActionController(object):
 
     Implements the API for stack actions
     """
-    # Define request scope (must match what is in policy.json)
+    # Define request scope (must match what is in policy.json or policies in
+    # code)
     REQUEST_SCOPE = 'actions'
 
     ACTIONS = (
-        SUSPEND, RESUME, CHECK, CANCEL_UPDATE
+        SUSPEND, RESUME, CHECK,
+        CANCEL_UPDATE, CANCEL_WITHOUT_ROLLBACK
     ) = (
-        'suspend', 'resume', 'check', 'cancel_update'
+        'suspend', 'resume', 'check',
+        'cancel_update', 'cancel_without_rollback'
     )
 
     def __init__(self, options):
         self.options = options
         self.rpc_client = rpc_client.EngineClient()
 
-    @util.identified_stack
+    @util.registered_identified_stack
     def action(self, req, identity, body=None):
         """Performs a specified action on a stack.
 
@@ -64,7 +67,11 @@ class ActionController(object):
         elif ac == self.CHECK:
             self.rpc_client.stack_check(req.context, identity)
         elif ac == self.CANCEL_UPDATE:
-            self.rpc_client.stack_cancel_update(req.context, identity)
+            self.rpc_client.stack_cancel_update(req.context, identity,
+                                                cancel_with_rollback=True)
+        elif ac == self.CANCEL_WITHOUT_ROLLBACK:
+            self.rpc_client.stack_cancel_update(req.context, identity,
+                                                cancel_with_rollback=False)
         else:
             raise exc.HTTPInternalServerError(_("Unexpected action %s") % ac)
 
