@@ -47,6 +47,9 @@ service_opts = [
                help=_('URL of the Heat waitcondition server.')),
     cfg.StrOpt('heat_watch_server_url',
                default="",
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch Service has been removed.',
+               deprecated_since='10.0.0',
                help=_('URL of the Heat CloudWatch server.')),
     cfg.StrOpt('instance_connection_is_secure',
                default="0",
@@ -179,6 +182,9 @@ engine_opts = [
                       ' for stack locking.')),
     cfg.BoolOpt('enable_cloud_watch_lite',
                 default=False,
+                deprecated_for_removal=True,
+                deprecated_reason='Heat CloudWatch Service has been removed.',
+                deprecated_since='10.0.0',
                 help=_('Enable the legacy OS::Heat::CWLiteAlarm resource.')),
     cfg.BoolOpt('enable_stack_abandon',
                 default=False,
@@ -281,6 +287,7 @@ engine_opts = [
 rpc_opts = [
     cfg.StrOpt('host',
                default=socket.gethostname(),
+               sample_default='<Hostname>',
                help=_('Name of the engine node. '
                       'This can be an opaque identifier. '
                       'It is not necessarily a hostname, FQDN, '
@@ -369,6 +376,13 @@ volumes_opts = [
                        "This is a temporary workaround until cinder-backup "
                        "service becomes discoverable, see LP#1334856."))]
 
+noauth_group = cfg.OptGroup('noauth')
+noauth_opts = [
+    cfg.StrOpt('token_response',
+               default='',
+               help=_("JSON file containing the content returned by the "
+                      "noauth middleware."))]
+
 
 def startup_sanity_check():
     if (not cfg.CONF.stack_user_domain_id and
@@ -403,13 +417,14 @@ def list_opts():
     yield auth_password_group.name, auth_password_opts
     yield revision_group.name, revision_opts
     yield volumes_group.name, volumes_opts
+    yield noauth_group.name, noauth_opts
     yield profiler.list_opts()[0]
     yield 'clients', default_clients_opts
 
     for client in ('aodh', 'barbican', 'ceilometer', 'cinder', 'designate',
                    'glance', 'heat', 'keystone', 'magnum', 'manila', 'mistral',
-                   'monasca', 'neutron', 'nova', 'sahara', 'senlin', 'swift',
-                   'trove', 'zaqar'
+                   'monasca', 'neutron', 'nova', 'octavia', 'sahara', 'senlin',
+                   'swift', 'trove', 'zaqar'
                    ):
         client_specific_group = 'clients_' + client
         yield client_specific_group, clients_opts
