@@ -20,9 +20,12 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_policy import policy
+from oslo_utils import excutils
 import six
 
 from heat.common import exception
+from heat.common.i18n import _
+from heat import policies
 
 
 CONF = cfg.CONF
@@ -44,6 +47,10 @@ class Enforcer(object):
         self.default_rule = default_rule
         self.enforcer = policy.Enforcer(
             CONF, default_rule=default_rule, policy_file=policy_file)
+        self.log_not_registered = True
+
+        # register rules
+        self.enforcer.register_defaults(policies.list_rules())
 
     def set_rules(self, rules, overwrite=True):
         """Create a new Rules object based on the provided dict of rules."""
@@ -54,7 +61,8 @@ class Enforcer(object):
         """Set the rules found in the json file on disk."""
         self.enforcer.load_rules(force_reload)
 
-    def _check(self, context, rule, target, exc, *args, **kwargs):
+    def _check(self, context, rule, target, exc,
+               is_registered_policy=False, *args, **kwargs):
         """Verifies that the action is valid on the target in this context.
 
            :param context: Heat request context
@@ -65,10 +73,23 @@ class Enforcer(object):
         """
         do_raise = False if not exc else True
         credentials = context.to_policy_values()
-        return self.enforcer.enforce(rule, target, credentials,
-                                     do_raise, exc=exc, *args, **kwargs)
+        if is_registered_policy:
+            try:
+                return self.enforcer.authorize(rule, target, credentials,
+                                               do_raise=do_raise,
+                                               exc=exc, action=rule)
+            except policy.PolicyNotRegistered:
+                if self.log_not_registered:
+                    with excutils.save_and_reraise_exception():
+                        LOG.exception(_('Policy not registered.'))
+                else:
+                    raise
+        else:
+            return self.enforcer.enforce(rule, target, credentials,
+                                         do_raise, exc=exc, *args, **kwargs)
 
-    def enforce(self, context, action, scope=None, target=None):
+    def enforce(self, context, action, scope=None, target=None,
+                is_registered_policy=False):
         """Verifies that the action is valid on the target in this context.
 
            :param context: Heat request context
@@ -79,15 +100,20 @@ class Enforcer(object):
         """
         _action = '%s:%s' % (scope or self.scope, action)
         _target = target or {}
-        return self._check(context, _action, _target, self.exc, action=action)
+        return self._check(context, _action, _target, self.exc, action=action,
+                           is_registered_policy=is_registered_policy)
 
     def check_is_admin(self, context):
-        """Whether or not roles contains 'admin' role according to policy.json.
+        """Whether or not is admin according to policy.
+
+        By default the rule will check whether or not roles contains
+        'admin' role and is admin project.
 
            :param context: Heat request context
            :returns: A non-False value if the user is admin according to policy
         """
-        return self._check(context, 'context_is_admin', target={}, exc=None)
+        return self._check(context, 'context_is_admin', target={}, exc=None,
+                           is_registered_policy=True)
 
 
 def get_enforcer():
@@ -102,13 +128,17 @@ class ResourceEnforcer(Enforcer):
                  **kwargs):
         super(ResourceEnforcer, self).__init__(
             default_rule=default_rule, **kwargs)
+        self.log_not_registered = False
 
-    def _enforce(self, context, res_type, scope=None, target=None):
+    def _enforce(self, context, res_type, scope=None, target=None,
+                 is_registered_policy=False):
         try:
             result = super(ResourceEnforcer, self).enforce(
                 context, res_type,
                 scope=scope or 'resource_types',
-                target=target)
+                target=target,  is_registered_policy=is_registered_policy)
+        except policy.PolicyNotRegistered:
+            result = True
         except self.exc as ex:
             LOG.info(six.text_type(ex))
             raise
@@ -117,19 +147,27 @@ class ResourceEnforcer(Enforcer):
                 raise self.exc(action=res_type)
         return result
 
-    def enforce(self, context, res_type, scope=None, target=None):
+    def enforce(self, context, res_type, scope=None, target=None,
+                is_registered_policy=False):
         # NOTE(pas-ha): try/except just to log the exception
-        result = self._enforce(context, res_type, scope, target)
+        result = self._enforce(context, res_type, scope, target,
+                               is_registered_policy=is_registered_policy)
 
         if result:
             # check for wildcard resource types
             subparts = res_type.split("::")[:-1]
             subparts.append('*')
             res_type_wc = "::".join(subparts)
-            return self._enforce(context, res_type_wc, scope, target)
+            try:
+                return self._enforce(context, res_type_wc, scope, target,
+                                     is_registered_policy=is_registered_policy)
+            except self.exc:
+                raise self.exc(action=res_type)
 
         return result
 
-    def enforce_stack(self, stack, scope=None, target=None):
+    def enforce_stack(self, stack, scope=None, target=None,
+                      is_registered_policy=False):
         for res in stack.resources.values():
-            self.enforce(stack.context, res.type(), scope=scope, target=target)
+            self.enforce(stack.context, res.type(), scope=scope, target=target,
+                         is_registered_policy=is_registered_policy)
