@@ -136,34 +136,58 @@ api_cw_opts = [
     cfg.IPOpt('bind_host', default='0.0.0.0',
               help=_('Address to bind the server. Useful when '
                      'selecting a particular network interface.'),
-              deprecated_group='DEFAULT'),
+              deprecated_group='DEFAULT',
+              deprecated_for_removal=True,
+              deprecated_reason='Heat CloudWatch API has been removed.',
+              deprecated_since='10.0.0'),
     cfg.PortOpt('bind_port', default=8003,
                 help=_('The port on which the server will listen.'),
-                deprecated_group='DEFAULT'),
+                deprecated_group='DEFAULT',
+                deprecated_for_removal=True,
+                deprecated_reason='Heat CloudWatch API has been removed.',
+                deprecated_since='10.0.0'),
     cfg.IntOpt('backlog', default=4096,
                help=_("Number of backlog requests "
                       "to configure the socket with."),
-               deprecated_group='DEFAULT'),
+               deprecated_group='DEFAULT',
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been removed.',
+               deprecated_since='10.0.0'),
     cfg.StrOpt('cert_file',
                help=_("Location of the SSL certificate file "
                       "to use for SSL mode."),
-               deprecated_group='DEFAULT'),
+               deprecated_group='DEFAULT',
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been Removed.',
+               deprecated_since='10.0.0'),
     cfg.StrOpt('key_file',
                help=_("Location of the SSL key file to use "
                       "for enabling SSL mode."),
-               deprecated_group='DEFAULT'),
+               deprecated_group='DEFAULT',
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been Removed.',
+               deprecated_since='10.0.0'),
     cfg.IntOpt('workers', min=0, default=1,
                help=_("Number of workers for Heat service."),
-               deprecated_group='DEFAULT'),
+               deprecated_group='DEFAULT',
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been Removed.',
+               deprecated_since='10.0.0'),
     cfg.IntOpt('max_header_line', default=16384,
                help=_('Maximum line size of message headers to be accepted. '
                       'max_header_line may need to be increased when using '
                       'large tokens (typically those generated by the '
-                      'Keystone v3 API with big service catalogs.)')),
+                      'Keystone v3 API with big service catalogs.)'),
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been Removed.',
+               deprecated_since='10.0.0'),
     cfg.IntOpt('tcp_keepidle', default=600,
                help=_('The value for the socket option TCP_KEEPIDLE.  This is '
                       'the time in seconds that the connection must be idle '
-                      'before TCP starts sending keepalive probes.')),
+                      'before TCP starts sending keepalive probes.'),
+               deprecated_for_removal=True,
+               deprecated_reason='Heat CloudWatch API has been Removed.',
+               deprecated_since='10.0.0')
 ]
 api_cw_group = cfg.OptGroup('heat_api_cloudwatch')
 cfg.CONF.register_group(api_cw_group)
