@@ -51,10 +51,6 @@ def extract_args(params):
             bool_value = param_utils.extract_bool(name, params[name])
             kwargs[name] = bool_value
 
-    name = rpc_api.PARAM_SHOW_DELETED
-    if name in params:
-        params[name] = param_utils.extract_bool(name, params[name])
-
     adopt_data = params.get(rpc_api.PARAM_ADOPT_STACK_DATA)
     if adopt_data:
         try:
@@ -237,7 +233,8 @@ def format_stack(stack, preview=False, resolve_outputs=True):
         info.update(update_info)
 
     # allow users to view the outputs of stacks
-    if stack.action != stack.DELETE and resolve_outputs:
+    if (not (stack.action == stack.DELETE and stack.status == stack.COMPLETE)
+            and resolve_outputs):
         info[rpc_api.STACK_OUTPUTS] = format_stack_outputs(stack.outputs,
                                                            resolve_value=True)
 
@@ -528,6 +525,15 @@ def format_validate_parameter(param):
     if param.user_value:
         res[rpc_api.PARAM_VALUE] = param.user_value
 
+    if param.tags():
+        res[rpc_api.PARAM_TAG] = param.tags()
+
+    _build_parameter_constraints(res, param)
+
+    return res
+
+
+def _build_parameter_constraints(res, param):
     constraint_description = []
 
     # build constraints
@@ -569,8 +575,6 @@ def format_validate_parameter(param):
         res[rpc_api.PARAM_CONSTRAINT_DESCRIPTION] = " ".join(
             constraint_description)
 
-    return res
-
 
 def format_software_config(sc, detail=True, include_project=False):
     if sc is None:
