@@ -17,7 +17,6 @@ from oslo_utils import strutils
 import six
 
 from heat.common.i18n import _
-from heat.common.i18n import _LW
 from heat.common.i18n import repr_wrapper
 from heat.engine import constraints as constr
 from heat.engine import support
@@ -133,6 +132,13 @@ def _stack_id_output(resource_name, template_type='cfn'):
         }
 
 
+BASE_ATTRIBUTES = (SHOW_ATTR, ) = ('show', )
+
+# Returned by function.dep_attrs() to indicate that all attributes are
+# referenced
+ALL_ATTRIBUTES = '*'
+
+
 @repr_wrapper
 class Attributes(collections.Mapping):
     """Models a collection of Resource Attributes."""
@@ -140,12 +146,33 @@ class Attributes(collections.Mapping):
     def __init__(self, res_name, schema, resolver):
         self._resource_name = res_name
         self._resolver = resolver
-        self._attributes = Attributes._make_attributes(schema)
+        self.set_schema(schema)
         self.reset_resolved_values()
 
+        assert ALL_ATTRIBUTES not in schema, \
+            "Invalid attribute name '%s'" % ALL_ATTRIBUTES
+
     def reset_resolved_values(self):
+        if hasattr(self, '_resolved_values'):
+            self._has_new_resolved = len(self._resolved_values) > 0
+        else:
+            self._has_new_resolved = False
         self._resolved_values = {}
 
+    def set_schema(self, schema):
+        self._attributes = self._make_attributes(schema)
+
+    def get_cache_mode(self, attribute_name):
+        """Return the cache mode for the specified attribute.
+
+        If the attribute is not defined in the schema, the default cache
+        mode (CACHE_LOCAL) is returned.
+        """
+        try:
+            return self._attributes[attribute_name].schema.cache_mode
+        except KeyError:
+            return Schema.CACHE_LOCAL
+
     @staticmethod
     def _make_attributes(schema):
         return dict((n, Attribute(n, d)) for n, d in schema.items())
@@ -182,38 +209,62 @@ class Attributes(collections.Mapping):
     def _validate_type(self, attrib, value):
         if attrib.schema.type == attrib.schema.STRING:
             if not isinstance(value, six.string_types):
-                LOG.warning(_LW("Attribute %(name)s is not of type "
-                                "%(att_type)s"),
+                LOG.warning("Attribute %(name)s is not of type "
+                            "%(att_type)s",
                             {'name': attrib.name,
                              'att_type': attrib.schema.STRING})
         elif attrib.schema.type == attrib.schema.LIST:
             if (not isinstance(value, collections.Sequence)
                     or isinstance(value, six.string_types)):
-                LOG.warning(_LW("Attribute %(name)s is not of type "
-                                "%(att_type)s"),
+                LOG.warning("Attribute %(name)s is not of type "
+                            "%(att_type)s",
                             {'name': attrib.name,
                              'att_type': attrib.schema.LIST})
         elif attrib.schema.type == attrib.schema.MAP:
             if not isinstance(value, collections.Mapping):
-                LOG.warning(_LW("Attribute %(name)s is not of type "
-                                "%(att_type)s"),
+                LOG.warning("Attribute %(name)s is not of type "
+                            "%(att_type)s",
                             {'name': attrib.name,
                              'att_type': attrib.schema.MAP})
         elif attrib.schema.type == attrib.schema.INTEGER:
             if not isinstance(value, int):
-                LOG.warning(_LW("Attribute %(name)s is not of type "
-                                "%(att_type)s"),
+                LOG.warning("Attribute %(name)s is not of type "
+                            "%(att_type)s",
                             {'name': attrib.name,
                              'att_type': attrib.schema.INTEGER})
         elif attrib.schema.type == attrib.schema.BOOLEAN:
             try:
                 strutils.bool_from_string(value, strict=True)
             except ValueError:
-                LOG.warning(_LW("Attribute %(name)s is not of type "
-                                "%(att_type)s"),
+                LOG.warning("Attribute %(name)s is not of type "
+                            "%(att_type)s",
                             {'name': attrib.name,
                              'att_type': attrib.schema.BOOLEAN})
 
+    @property
+    def cached_attrs(self):
+        return self._resolved_values
+
+    @cached_attrs.setter
+    def cached_attrs(self, c_attrs):
+        if c_attrs is None:
+            self._resolved_values = {}
+        else:
+            self._resolved_values = c_attrs
+        self._has_new_resolved = False
+
+    def set_cached_attr(self, key, value):
+        self._resolved_values[key] = value
+        self._has_new_resolved = True
+
+    def has_new_cached_attrs(self):
+        """Returns True if cached_attrs have changed
+
+        Allows the caller to determine if this instance's cached_attrs
+        have been updated since they were initially set (if at all).
+        """
+        return self._has_new_resolved
+
     def __getitem__(self, key):
         if key not in self:
             raise KeyError(_('%(resource)s: Invalid attribute %(key)s') %
@@ -233,7 +284,7 @@ class Attributes(collections.Mapping):
             self._validate_type(attrib, value)
             # only store if not None, it may resolve to an actual value
             # on subsequent calls
-            self._resolved_values[key] = value
+            self.set_cached_attr(key, value)
         return value
 
     def __len__(self):
@@ -250,34 +301,6 @@ class Attributes(collections.Mapping):
                 '\n\t'.join(six.itervalues(self)))
 
 
-class DynamicSchemeAttributes(Attributes):
-    """The collection of attributes for resources without static attr scheme.
-
-    The class defines collection of attributes for such entities as Resource
-    Group, Software Deployment and so on that doesn't have static attribute
-    scheme. The attribute scheme for such kind of resources can contain
-    attribute from attribute scheme (like other resources) and dynamic
-    attributes (nested stack attrs or API response attrs).
-    """
-
-    def __getitem__(self, key):
-        try:
-            # check if the value can be resolved with attributes
-            # in attributes schema (static attributes)
-            return super(DynamicSchemeAttributes, self).__getitem__(key)
-        except KeyError:
-            # ok, the attribute is not present in attribute scheme
-            # try to check the attributes dynamically
-            if key in self._resolved_values:
-                return self._resolved_values[key]
-
-            value = self._resolver(key)
-            if value is not None:
-                self._resolved_values[key] = value
-
-            return value
-
-
 def select_from_attribute(attribute_value, path):
     """Select an element from an attribute value.
 
