@@ -11,8 +11,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from designateclient import client
 from designateclient import exceptions
-from designateclient import v1 as client
 from designateclient.v1 import domains
 from designateclient.v1 import records
 
@@ -29,9 +29,14 @@ class DesignateClientPlugin(client_plugin.ClientPlugin):
 
     service_types = [DNS] = ['dns']
 
-    def _create(self):
+    supported_versions = [V1, V2] = ['1', '2']
+
+    default_version = V1
+
+    def _create(self, version=default_version):
         endpoint_type = self._get_client_option(CLIENT_NAME, 'endpoint_type')
-        return client.Client(session=self.context.keystone_session,
+        return client.Client(version=version,
+                             session=self.context.keystone_session,
                              endpoint_type=endpoint_type,
                              service_type=self.DNS,
                              region_name=self._get_region_name())
@@ -51,6 +56,19 @@ class DesignateClientPlugin(client_plugin.ClientPlugin):
         raise heat_exception.EntityNotFound(entity='Designate Domain',
                                             name=domain_id_or_name)
 
+    def get_zone_id(self, zone_id_or_name):
+        try:
+            zone_obj = self.client(version=self.V2).zones.get(zone_id_or_name)
+            return zone_obj['id']
+        except exceptions.NotFound:
+            zones = self.client().zones.list(
+                criterion=dict(name=zone_id_or_name))
+            if len(zones) == 1:
+                    return zones[0]['id']
+
+        raise heat_exception.EntityNotFound(entity='Designate Zone',
+                                            name=zone_id_or_name)
+
     def domain_create(self, **kwargs):
         domain = domains.Domain(**kwargs)
         return self.client().domains.create(domain)
@@ -90,6 +108,10 @@ class DesignateClientPlugin(client_plugin.ClientPlugin):
 
 
 class DesignateDomainConstraint(constraints.BaseCustomConstraint):
-
     resource_client_name = CLIENT_NAME
     resource_getter_name = 'get_domain_id'
+
+
+class DesignateZoneConstraint(constraints.BaseCustomConstraint):
+    resource_client_name = CLIENT_NAME
+    resource_getter_name = 'get_zone_id'
