@@ -12,7 +12,6 @@
 #    under the License.
 
 from oslo_config import cfg
-import six
 
 from heatclient import client as hc
 from heatclient import exc
@@ -89,14 +88,5 @@ class HeatClientPlugin(client_plugin.ClientPlugin):
             config_url += '/'
         return config_url
 
-    def get_watch_server_url(self):
-        cfn_url = self.get_heat_cfn_url()
-        url_parts = cfn_url.split(':')
-        port_and_version = url_parts[-1].split('/')
-        port_and_version[0] = (
-            six.text_type(cfg.CONF.heat_api_cloudwatch.bind_port))
-        url_parts[-1] = '/'.join(port_and_version)
-        return ':'.join(url_parts)
-
     def get_insecure_option(self):
         return self._get_client_option(CLIENT_NAME, 'insecure')
