@@ -19,17 +19,20 @@ import os
 import pkgutil
 import string
 
+from neutronclient.common import exceptions as q_exceptions
 from novaclient import client as nc
 from novaclient import exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
+from oslo_utils import netutils
 import six
 from six.moves.urllib import parse as urlparse
 import tenacity
 
 from heat.common import exception
 from heat.common.i18n import _
+from heat.engine.clients import client_exception
 from heat.engine.clients import client_plugin
 from heat.engine.clients import os as os_client
 from heat.engine import constraints
@@ -100,7 +103,8 @@ class NovaClientPlugin(client_plugin.ClientPlugin):
         return client
 
     def is_not_found(self, ex):
-        return isinstance(ex, exceptions.NotFound)
+        return isinstance(ex, (exceptions.NotFound,
+                               q_exceptions.NotFound))
 
     def is_over_limit(self, ex):
         return isinstance(ex, exceptions.OverLimit)
@@ -672,6 +676,54 @@ echo -e '%s\tALL=(ALL)\tNOPASSWD: ALL' >> /etc/sudoers
                       {'att': attach_id, 'srv': server_id})
             return False
 
+    def associate_floatingip(self, server_id, floatingip_id):
+        iface_list = self.fetch_server(server_id).interface_list()
+        if len(iface_list) == 0:
+            raise client_exception.InterfaceNotFound(id=server_id)
+        if len(iface_list) > 1:
+            LOG.warning("Multiple interfaces found for server %s, "
+                        "using the first one.", server_id)
+
+        port_id = iface_list[0].port_id
+        fixed_ips = iface_list[0].fixed_ips
+        fixed_address = next(ip['ip_address'] for ip in fixed_ips
+                             if netutils.is_valid_ipv4(ip['ip_address']))
+        request_body = {
+            'floatingip': {
+                'port_id': port_id,
+                'fixed_ip_address': fixed_address}}
+
+        self.clients.client('neutron').update_floatingip(floatingip_id,
+                                                         request_body)
+
+    def dissociate_floatingip(self, floatingip_id):
+        request_body = {
+            'floatingip': {
+                'port_id': None,
+                'fixed_ip_address': None}}
+        self.clients.client('neutron').update_floatingip(floatingip_id,
+                                                         request_body)
+
+    def associate_floatingip_address(self, server_id, fip_address):
+        fips = self.clients.client(
+            'neutron').list_floatingips(
+                floating_ip_address=fip_address)['floatingips']
+        if len(fips) == 0:
+            args = {'ip_address': fip_address}
+            raise client_exception.EntityMatchNotFound(entity='floatingip',
+                                                       args=args)
+        self.associate_floatingip(server_id, fips[0]['id'])
+
+    def dissociate_floatingip_address(self, fip_address):
+        fips = self.clients.client(
+            'neutron').list_floatingips(
+                floating_ip_address=fip_address)['floatingips']
+        if len(fips) == 0:
+            args = {'ip_address': fip_address}
+            raise client_exception.EntityMatchNotFound(entity='floatingip',
+                                                       args=args)
+        self.dissociate_floatingip(fips[0]['id'])
+
     def interface_detach(self, server_id, port_id):
         with self.ignore_not_found:
             server = self.fetch_server(server_id)
