@@ -947,12 +947,16 @@ class Repeat(function.Function):
         keys, lists = six.moves.zip(*for_each.items())
 
         # use empty list for references(None) else validation will fail
-        values = [[] if value is None else value for value in lists]
         value_lens = []
-        for arg in values:
-            self._valid_arg(arg)
-            value_lens.append(len(arg))
-        if not self._nested_loop:
+        values = []
+        for value in lists:
+            if value is None:
+                values.append([])
+            else:
+                self._valid_arg(value)
+                values.append(value)
+                value_lens.append(len(value))
+        if not self._nested_loop and value_lens:
             if len(set(value_lens)) != 1:
                 raise ValueError(_('For %s, the length of for_each values '
                                    'should be equal if no nested '
@@ -1469,10 +1473,17 @@ class MakeURL(function.Function):
                             try:
                                 port = int(port)
                             except ValueError:
-                                raise ValueError(_('Invalid URL port "%s"') %
-                                                 port)
+                                raise ValueError(
+                                    _('Invalid URL port "%(port)s" '
+                                      'for %(fn_name)s called with '
+                                      '%(args)s')
+                                    % {'fn_name': self.fn_name,
+                                       'port': port, 'args': args})
+
                         if not (0 < port <= 65535):
-                            raise ValueError(_('Invalid URL port %d') % port)
+                            raise ValueError(
+                                _('Invalid URL port %d, '
+                                  'must be in range 1-65535') % port)
                 else:
                     if not isinstance(args[arg], (function.Function,
                                                   six.string_types)):
