@@ -17,7 +17,6 @@ import six
 
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LI
 from heat.engine import attributes
 from heat.engine.clients import progress
 from heat.engine import constraints
@@ -52,12 +51,12 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
         AVAILABILITY_ZONE_ATTR, SIZE_ATTR, SNAPSHOT_ID_ATTR, DISPLAY_NAME_ATTR,
         DISPLAY_DESCRIPTION_ATTR, VOLUME_TYPE_ATTR, METADATA_ATTR,
         SOURCE_VOLID_ATTR, STATUS, CREATED_AT, BOOTABLE, METADATA_VALUES_ATTR,
-        ENCRYPTED_ATTR, ATTACHMENTS, MULTI_ATTACH_ATTR,
+        ENCRYPTED_ATTR, ATTACHMENTS, ATTACHMENTS_LIST, MULTI_ATTACH_ATTR,
     ) = (
         'availability_zone', 'size', 'snapshot_id', 'display_name',
         'display_description', 'volume_type', 'metadata',
         'source_volid', 'status', 'created_at', 'bootable', 'metadata_values',
-        'encrypted', 'attachments', 'multiattach',
+        'encrypted', 'attachments', 'attachments_list', 'multiattach',
     )
 
     properties_schema = {
@@ -221,9 +220,25 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
             type=attributes.Schema.STRING
         ),
         ATTACHMENTS: attributes.Schema(
-            _('The list of attachments of the volume.'),
+            _('A string representation of the list of attachments of the '
+              'volume.'),
+            type=attributes.Schema.STRING,
             cache_mode=attributes.Schema.CACHE_NONE,
-            type=attributes.Schema.STRING
+            support_status=support.SupportStatus(
+                status=support.DEPRECATED,
+                message=_('Use property %s.') % ATTACHMENTS_LIST,
+                version='9.0.0',
+                previous_status=support.SupportStatus(
+                    status=support.SUPPORTED,
+                    version='2015.1'
+                )
+            )
+        ),
+        ATTACHMENTS_LIST: attributes.Schema(
+            _('The list of attachments of the volume.'),
+            type=attributes.Schema.LIST,
+            cache_mode=attributes.Schema.CACHE_NONE,
+            support_status=support.SupportStatus(version='9.0.0'),
         ),
         MULTI_ATTACH_ATTR: attributes.Schema(
             _('Boolean indicating whether allow the volume to be attached '
@@ -295,6 +310,8 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
             return vol.name
         elif name == self.DISPLAY_DESCRIPTION_ATTR:
             return vol.description
+        elif name == self.ATTACHMENTS_LIST:
+            return vol.attachments
         return six.text_type(getattr(vol, name))
 
     def check_create_complete(self, vol_id):
@@ -346,18 +363,18 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
     def _check_extend_volume_complete(self):
         vol = self.client().volumes.get(self.resource_id)
         if vol.status == 'extending':
-            LOG.debug("Volume %s is being extended" % vol.id)
+            LOG.debug("Volume %s is being extended", vol.id)
             return False
 
         if vol.status != 'available':
-            LOG.info(_LI("Resize failed: Volume %(vol)s "
-                         "is in %(status)s state."),
+            LOG.info("Resize failed: Volume %(vol)s "
+                     "is in %(status)s state.",
                      {'vol': vol.id, 'status': vol.status})
             raise exception.ResourceUnknownStatus(
                 resource_status=vol.status,
                 result=_('Volume resize failed'))
 
-        LOG.info(_LI('Volume %(id)s resize complete'), {'id': vol.id})
+        LOG.info('Volume %(id)s resize complete', {'id': vol.id})
         return True
 
     def _backup_restore(self, vol_id, backup_id):
@@ -377,17 +394,17 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
     def _check_backup_restore_complete(self):
         vol = self.client().volumes.get(self.resource_id)
         if vol.status == 'restoring-backup':
-            LOG.debug("Volume %s is being restoring from backup" % vol.id)
+            LOG.debug("Volume %s is being restoring from backup", vol.id)
             return False
 
         if vol.status != 'available':
-            LOG.info(_LI("Restore failed: Volume %(vol)s is in %(status)s "
-                         "state."), {'vol': vol.id, 'status': vol.status})
+            LOG.info("Restore failed: Volume %(vol)s is in %(status)s "
+                     "state.", {'vol': vol.id, 'status': vol.status})
             raise exception.ResourceUnknownStatus(
                 resource_status=vol.status,
                 result=_('Volume backup restore failed'))
 
-        LOG.info(_LI('Volume %(id)s backup restore complete'), {'id': vol.id})
+        LOG.info('Volume %s backup restore complete', vol.id)
         return True
 
     def needs_replace_failed(self):
@@ -659,8 +676,8 @@ class CinderVolume(vb.BaseVolume, sh.SchedulerHintsMixin):
 
         if (resource_data.get(self.METADATA) and
                 resource_data.get(self.METADATA).get(
-                    self.READ_ONLY) is not None):
-            read_only = resource_data.get(self.METADATA).pop(self.READ_ONLY)
+                    'readonly') is not None):
+            read_only = resource_data.get(self.METADATA).pop('readonly')
             volume_reality.update({self.READ_ONLY: read_only})
 
         old_vt = self.data().get(self.VOLUME_TYPE)
