@@ -19,6 +19,7 @@ from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
 from heat.engine.resources import server_base
+from heat.engine import support
 
 cfg.CONF.import_opt('default_software_config_transport', 'heat.common.config')
 cfg.CONF.import_opt('default_user_data_format', 'heat.common.config')
@@ -36,9 +37,11 @@ class DeployedServer(server_base.BaseServer):
     """
 
     PROPERTIES = (
-        NAME, METADATA, SOFTWARE_CONFIG_TRANSPORT
+        NAME, METADATA, SOFTWARE_CONFIG_TRANSPORT,
+        DEPLOYMENT_SWIFT_DATA
     ) = (
-        'name', 'metadata', 'software_config_transport'
+        'name', 'metadata', 'software_config_transport',
+        'deployment_swift_data'
     )
 
     _SOFTWARE_CONFIG_TRANSPORTS = (
@@ -47,6 +50,12 @@ class DeployedServer(server_base.BaseServer):
         'POLL_SERVER_CFN', 'POLL_SERVER_HEAT', 'POLL_TEMP_URL', 'ZAQAR_MESSAGE'
     )
 
+    _DEPLOYMENT_SWIFT_DATA_KEYS = (
+        CONTAINER, OBJECT
+    ) = (
+        'container', 'object',
+    )
+
     properties_schema = {
         NAME: properties.Schema(
             properties.Schema.STRING,
@@ -59,7 +68,16 @@ class DeployedServer(server_base.BaseServer):
               'keys and values must be 255 characters or less. Non-string '
               'values will be serialized to JSON (and the serialized '
               'string must be 255 characters or less).'),
-            update_allowed=True
+            update_allowed=True,
+            support_status=support.SupportStatus(
+                status=support.DEPRECATED,
+                message='This property will be ignored',
+                version='9.0.0',
+                previous_status=support.SupportStatus(
+                    status=support.SUPPORTED,
+                    version='8.0.0'
+                )
+            )
         ),
         SOFTWARE_CONFIG_TRANSPORT: properties.Schema(
             properties.Schema.STRING,
@@ -78,19 +96,58 @@ class DeployedServer(server_base.BaseServer):
                 constraints.AllowedValues(_SOFTWARE_CONFIG_TRANSPORTS),
             ]
         ),
+        DEPLOYMENT_SWIFT_DATA: properties.Schema(
+            properties.Schema.MAP,
+            _('Swift container and object to use for storing deployment data '
+              'for the server resource. The parameter is a map value '
+              'with the keys "container" and "object", and the values '
+              'are the corresponding container and object names. The '
+              'software_config_transport parameter must be set to '
+              'POLL_TEMP_URL for swift to be used. If not specified, '
+              'and software_config_transport is set to POLL_TEMP_URL, a '
+              'container will be automatically created from the resource '
+              'name, and the object name will be a generated uuid.'),
+            support_status=support.SupportStatus(version='9.0.0'),
+            default={},
+            update_allowed=True,
+            schema={
+                CONTAINER: properties.Schema(
+                    properties.Schema.STRING,
+                    _('Name of the container.'),
+                    constraints=[
+                        constraints.Length(min=1)
+                    ]
+                ),
+                OBJECT: properties.Schema(
+                    properties.Schema.STRING,
+                    _('Name of the object.'),
+                    constraints=[
+                        constraints.Length(min=1)
+                    ]
+                )
+            }
+        )
     }
 
     ATTRIBUTES = (
-        NAME_ATTR
+        NAME_ATTR, OS_COLLECT_CONFIG
     ) = (
-        'name'
+        'name', 'os_collect_config'
     )
 
     attributes_schema = {
         NAME_ATTR: attributes.Schema(
             _('Name of the server.'),
             type=attributes.Schema.STRING
-        )
+        ),
+        OS_COLLECT_CONFIG: attributes.Schema(
+            _('The os-collect-config configuration for the server\'s local '
+              'agent to be configured to connect to Heat to retrieve '
+              'deployment data.'),
+            type=attributes.Schema.MAP,
+            support_status=support.SupportStatus(version='9.0.0'),
+            cache_mode=attributes.Schema.CACHE_NONE
+        ),
     }
 
     def __init__(self, name, json_snippet, stack):
