@@ -16,22 +16,17 @@ import six
 
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LE
-from heat.common.i18n import _LI
 from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
-from heat.engine import resource
 from heat.engine.resources import signal_responder
 from heat.engine import support
-from heat.scaling import cooldown
 from heat.scaling import scalingutil as sc_util
 
 LOG = logging.getLogger(__name__)
 
 
-class AutoScalingPolicy(cooldown.CooldownMixin,
-                        signal_responder.SignalResponder):
+class AutoScalingPolicy(signal_responder.SignalResponder):
     """A resource to manage scaling of `OS::Heat::AutoScalingGroup`.
 
     **Note** while it may incidentally support
@@ -162,7 +157,7 @@ class AutoScalingPolicy(cooldown.CooldownMixin,
             alarm_state = details.get('current',
                                       details.get('state', 'alarm')).lower()
 
-        LOG.info(_LI('Alarm %(name)s, new state %(state)s'),
+        LOG.info('Alarm %(name)s, new state %(state)s',
                  {'name': self.name, 'state': alarm_state})
 
         asgn_id = self.properties[self.AUTO_SCALING_GROUP_NAME]
@@ -174,34 +169,18 @@ class AutoScalingPolicy(cooldown.CooldownMixin,
                                        ) % {'alarm': self.name,
                                             'group': asgn_id})
 
-        self._check_scaling_allowed()
+        LOG.info('%(name)s alarm, adjusting group %(group)s with id '
+                 '%(asgn_id)s by %(filter)s',
+                 {'name': self.name, 'group': group.name,
+                  'asgn_id': asgn_id,
+                  'filter': self.properties[self.SCALING_ADJUSTMENT]})
 
-        LOG.info(_LI('%(name)s alarm, adjusting group %(group)s with id '
-                     '%(asgn_id)s by %(filter)s') % {
-            'name': self.name, 'group': group.name,
-            'asgn_id': asgn_id,
-            'filter': self.properties[self.SCALING_ADJUSTMENT]})
-
-        size_changed = False
-        try:
+        with group.frozen_properties():
             group.adjust(
                 self.properties[self.SCALING_ADJUSTMENT],
                 self.properties[self.ADJUSTMENT_TYPE],
-                self.properties[self.MIN_ADJUSTMENT_STEP])
-            size_changed = True
-        except resource.NoActionRequired:
-            raise
-        except Exception:
-            LOG.error(_LE("Error in performing scaling adjustment with "
-                          "%(name)s alarm for group %(group)s.") % {
-                'name': self.name,
-                'group': group.name})
-            raise
-        finally:
-            self._finished_scaling("%s : %s" % (
-                self.properties[self.ADJUSTMENT_TYPE],
-                self.properties[self.SCALING_ADJUSTMENT]),
-                size_changed=size_changed)
+                self.properties[self.MIN_ADJUSTMENT_STEP],
+                self.properties[self.COOLDOWN])
 
     def _resolve_attribute(self, name):
         if self.resource_id is None:
@@ -211,9 +190,6 @@ class AutoScalingPolicy(cooldown.CooldownMixin,
         elif name == self.SIGNAL_URL:
             return six.text_type(self._get_heat_signal_url())
 
-    def get_reference_id(self):
-        return resource.Resource.get_reference_id(self)
-
 
 def resource_mapping():
     return {
