@@ -24,11 +24,18 @@ from heat.engine import support
 class Bay(resource.Resource):
     """A resource that creates a Magnum Bay.
 
-    This resource creates a Magnum bay, which is a
-    collection of node objects where work is scheduled.
+    This resource has been deprecated in favor of OS::Magnum::Cluster.
     """
 
-    support_status = support.SupportStatus(version='6.0.0')
+    deprecation_msg = _('Please use OS::Magnum::Cluster instead.')
+    support_status = support.SupportStatus(
+        status=support.DEPRECATED,
+        message=deprecation_msg,
+        version='9.0.0',
+        previous_status=support.SupportStatus(
+            status=support.SUPPORTED,
+            version='6.0.0')
+    )
 
     PROPERTIES = (
         NAME, BAYMODEL, NODE_COUNT, MASTER_COUNT, DISCOVERY_URL,
@@ -55,13 +62,15 @@ class Bay(resource.Resource):
             properties.Schema.INTEGER,
             _('The node count for this bay.'),
             constraints=[constraints.Range(min=1)],
-            update_allowed=True
+            update_allowed=True,
+            default=1
         ),
         MASTER_COUNT: properties.Schema(
             properties.Schema.INTEGER,
             _('The number of master nodes for this bay.'),
             constraints=[constraints.Range(min=1)],
-            update_allowed=True
+            update_allowed=True,
+            default=1
         ),
         DISCOVERY_URL: properties.Schema(
             properties.Schema.STRING,
@@ -119,13 +128,20 @@ class Bay(resource.Resource):
             self.client().bays.update(self.resource_id, patch)
             return self.resource_id
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        record_reality = {}
+
+        for key in [self.NODE_COUNT, self.MASTER_COUNT]:
+            record_reality.update({key: resource_data.get(key)})
+
+        return record_reality
+
     def check_update_complete(self, id):
         bay = self.client().bays.get(id)
-        if bay.status == 'UPDATE_IN_PROGRESS':
-            return False
-        # check for None due to Magnum bug
-        # https://bugs.launchpad.net/magnum/+bug/1507598
-        elif bay.status is None:
+        # Check update complete request might get status before the status
+        # got changed to update in progress, so we allow `CREATE_COMPLETE`
+        # for it.
+        if bay.status in ['UPDATE_IN_PROGRESS', 'CREATE_COMPLETE']:
             return False
         elif bay.status == 'UPDATE_COMPLETE':
             return True
