@@ -17,7 +17,6 @@ import six
 
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LI
 from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import properties
@@ -234,7 +233,7 @@ class ManilaShare(resource.Resource):
         if share_status == self.STATUS_CREATING:
             return False
         elif share_status == self.STATUS_AVAILABLE:
-            LOG.info(_LI('Applying access rules to created Share.'))
+            LOG.info('Applying access rules to created Share.')
             # apply access rules to created share. please note that it is not
             # possible to define rules for share with share_status = creating
             access_rules = self.properties.get(self.ACCESS_RULES)
@@ -338,6 +337,18 @@ class ManilaShare(resource.Resource):
                         access_level=rule.get(self.ACCESS_LEVEL)
                     )
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        result = super(ManilaShare, self).parse_live_resource_data(
+            resource_properties, resource_data)
+
+        rules = self.client().shares.access_list(self.resource_id)
+        result[self.ACCESS_RULES] = []
+        for rule in rules:
+            result[self.ACCESS_RULES].append(
+                {(k, v) for (k, v) in six.iteritems(rule)
+                 if k in self._ACCESS_RULE_PROPERTIES})
+        return result
+
 
 def resource_mapping():
     return {'OS::Manila::Share': ManilaShare}
