@@ -66,7 +66,6 @@ class ManilaShareNetwork(resource.Resource):
             properties.Schema.STRING,
             _('Nova network id.'),
             update_allowed=True,
-            constraints=[constraints.CustomConstraint('nova.network')]
         ),
         DESCRIPTION: properties.Schema(
             properties.Schema.STRING,
@@ -113,6 +112,8 @@ class ManilaShareNetwork(resource.Resource):
         return self.client().share_networks.get(self.resource_id)
 
     def _resolve_attribute(self, name):
+        if self.resource_id is None:
+            return
         network = self._request_network()
         return getattr(network, name, None)
 
@@ -128,44 +129,62 @@ class ManilaShareNetwork(resource.Resource):
             raise exception.ResourcePropertyConflict(self.NEUTRON_SUBNET,
                                                      self.NOVA_NETWORK)
 
-    def translation_rules(self, props):
-        if self.is_using_neutron():
-            translation_rules = [
-                translation.TranslationRule(
-                    props,
-                    translation.TranslationRule.RESOLVE,
-                    [self.NEUTRON_NETWORK],
-                    client_plugin=self.client_plugin('neutron'),
-                    finder='find_resourceid_by_name_or_id',
-                    entity='network'
-                ),
-                translation.TranslationRule(
-                    props,
-                    translation.TranslationRule.RESOLVE,
-                    [self.NEUTRON_SUBNET],
-                    client_plugin=self.client_plugin('neutron'),
-                    finder='find_resourceid_by_name_or_id',
-                    entity='subnet'
-                )
-            ]
-        else:
-            translation_rules = [
-                translation.TranslationRule(
-                    props,
-                    translation.TranslationRule.RESOLVE,
-                    [self.NOVA_NETWORK],
-                    client_plugin=self.client_plugin('nova'),
-                    finder='get_nova_network_id'
-                )
-            ]
+        if self.is_using_neutron() and self.properties[self.NOVA_NETWORK]:
+            msg = _('With Neutron enabled you need to pass Neutron network '
+                    'and Neutron subnet instead of Nova network')
+            raise exception.StackValidationFailed(message=msg)
 
+        if (self.properties[self.NEUTRON_NETWORK] and not
+                self.properties[self.NEUTRON_SUBNET]):
+            raise exception.ResourcePropertyDependency(
+                prop1=self.NEUTRON_NETWORK, prop2=self.NEUTRON_SUBNET)
+
+        if (self.properties[self.NEUTRON_NETWORK] and
+                self.properties[self.NEUTRON_SUBNET]):
+            plg = self.client_plugin('neutron')
+            subnet_id = plg.find_resourceid_by_name_or_id(
+                'subnet', self.properties[self.NEUTRON_SUBNET])
+            net_id = plg.network_id_from_subnet_id(subnet_id)
+            provided_net_id = plg.find_resourceid_by_name_or_id(
+                'network', self.properties[self.NEUTRON_NETWORK])
+            if net_id != provided_net_id:
+                msg = (_('Provided %(subnet)s does not belong '
+                         'to provided %(network)s.')
+                       % {'subnet': self.NEUTRON_SUBNET,
+                          'network': self.NEUTRON_NETWORK})
+                raise exception.StackValidationFailed(message=msg)
+
+    def translation_rules(self, props):
+        translation_rules = [
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.NEUTRON_NETWORK],
+                client_plugin=self.client_plugin('neutron'),
+                finder='find_resourceid_by_name_or_id',
+                entity='network'
+            ),
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.NEUTRON_SUBNET],
+                client_plugin=self.client_plugin('neutron'),
+                finder='find_resourceid_by_name_or_id',
+                entity='subnet'
+            )
+        ]
         return translation_rules
 
     def handle_create(self):
+        neutron_subnet_id = self.properties[self.NEUTRON_SUBNET]
+        neutron_net_id = self.properties[self.NEUTRON_NETWORK]
+        if neutron_subnet_id and not neutron_net_id:
+            neutron_net_id = self.client_plugin(
+                'neutron').network_id_from_subnet_id(neutron_subnet_id)
         network = self.client().share_networks.create(
             name=self.properties[self.NAME],
-            neutron_net_id=self.properties[self.NEUTRON_NETWORK],
-            neutron_subnet_id=self.properties[self.NEUTRON_SUBNET],
+            neutron_net_id=neutron_net_id,
+            neutron_subnet_id=neutron_subnet_id,
             nova_net_id=self.properties[self.NOVA_NETWORK],
             description=self.properties[self.DESCRIPTION])
         self.resource_id_set(network.id)
@@ -191,14 +210,33 @@ class ManilaShareNetwork(resource.Resource):
                     self.resource_id, service)
 
         if prop_diff:
+            neutron_subnet_id = prop_diff.get(self.NEUTRON_SUBNET)
+            neutron_net_id = prop_diff.get(self.NEUTRON_NETWORK)
+            if neutron_subnet_id and not neutron_net_id:
+                neutron_net_id = self.client_plugin(
+                    'neutron').network_id_from_subnet_id(neutron_subnet_id)
+
             self.client().share_networks.update(
                 self.resource_id,
                 name=prop_diff.get(self.NAME),
-                neutron_net_id=prop_diff.get(self.NEUTRON_NETWORK),
-                neutron_subnet_id=prop_diff.get(self.NEUTRON_SUBNET),
+                neutron_net_id=neutron_net_id,
+                neutron_subnet_id=neutron_subnet_id,
                 nova_net_id=prop_diff.get(self.NOVA_NETWORK),
                 description=prop_diff.get(self.DESCRIPTION))
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        result = super(ManilaShareNetwork, self).parse_live_resource_data(
+            resource_properties, resource_data)
+        sec_list = self.client().security_services.list(
+            search_opts={'share_network_id': self.resource_id})
+        result.update({
+            self.NOVA_NETWORK: resource_data.get('nova_net_id'),
+            self.NEUTRON_NETWORK: resource_data.get('neutron_net_id'),
+            self.NEUTRON_SUBNET: resource_data.get('neutron_subnet_id'),
+            self.SECURITY_SERVICES: [service.id for service in sec_list]}
+        )
+        return result
+
 
 def resource_mapping():
     return {'OS::Manila::ShareNetwork': ManilaShareNetwork}
