@@ -30,6 +30,8 @@ class Firewall(neutron.NeutronResource):
 
     required_service_extension = 'fwaas'
 
+    entity = 'firewall'
+
     PROPERTIES = (
         NAME, DESCRIPTION, ADMIN_STATE_UP, FIREWALL_POLICY_ID,
         VALUE_SPECS, SHARED,
@@ -135,9 +137,6 @@ class Firewall(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_firewall(self.resource_id)['firewall']
-
     def check_create_complete(self, data):
         attributes = self._show_resource()
         status = attributes['status']
@@ -182,6 +181,13 @@ class Firewall(neutron.NeutronResource):
                     'firewall resource.')
         return super(Firewall, self)._resolve_attribute(name)
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        result = super(Firewall, self).parse_live_resource_data(
+            resource_properties, resource_data)
+        if self.SHARED in result:
+            result.pop(self.SHARED)
+        return result
+
 
 class FirewallPolicy(neutron.NeutronResource):
     """A resource for the FirewallPolicy resource in Neutron FWaaS.
@@ -192,6 +198,8 @@ class FirewallPolicy(neutron.NeutronResource):
 
     required_service_extension = 'fwaas'
 
+    entity = 'firewall_policy'
+
     PROPERTIES = (
         NAME, DESCRIPTION, SHARED, AUDITED, FIREWALL_RULES,
     ) = (
@@ -268,10 +276,6 @@ class FirewallPolicy(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_firewall_policy(self.resource_id)[
-            'firewall_policy']
-
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
@@ -304,6 +308,8 @@ class FirewallRule(neutron.NeutronResource):
 
     required_service_extension = 'fwaas'
 
+    entity = 'firewall_rule'
+
     PROPERTIES = (
         NAME, DESCRIPTION, SHARED, PROTOCOL, IP_VERSION,
         SOURCE_IP_ADDRESS, DESTINATION_IP_ADDRESS, SOURCE_PORT,
@@ -464,10 +470,6 @@ class FirewallRule(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_firewall_rule(
-            self.resource_id)['firewall_rule']
-
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
