@@ -43,8 +43,17 @@ class HealthMonitor(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
+    entity = 'health_monitor'
+
     support_status = support.SupportStatus(
-        support.DEPRECATED, DEPR_MSG, version='7.0.0'
+        status=support.HIDDEN,
+        version='9.0.0',
+        message=_('Use LBaaS V2 instead.'),
+        previous_status=support.SupportStatus(
+            status=support.DEPRECATED,
+            message=DEPR_MSG,
+            version='7.0.0'
+        )
     )
 
     PROPERTIES = (
@@ -172,10 +181,6 @@ class HealthMonitor(neutron.NeutronResource):
             {'health_monitor': properties})['health_monitor']
         self.resource_id_set(health_monitor['id'])
 
-    def _show_resource(self):
-        return self.client().show_health_monitor(
-            self.resource_id)['health_monitor']
-
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         if prop_diff:
             self.client().update_health_monitor(
@@ -202,8 +207,17 @@ class Pool(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
+    entity = 'pool'
+
     support_status = support.SupportStatus(
-        support.DEPRECATED, DEPR_MSG, version='7.0.0'
+        status=support.HIDDEN,
+        version='9.0.0',
+        message=_('Use LBaaS V2 instead.'),
+        previous_status=support.SupportStatus(
+            status=support.DEPRECATED,
+            message=DEPR_MSG,
+            version='7.0.0'
+        )
     )
 
     PROPERTIES = (
@@ -502,9 +516,6 @@ class Pool(neutron.NeutronResource):
 
         self.metadata_set({'vip': vip['id']})
 
-    def _show_resource(self):
-        return self.client().show_pool(self.resource_id)['pool']
-
     def check_create_complete(self, data):
         attributes = self._show_resource()
         status = attributes['status']
@@ -604,9 +615,18 @@ class PoolMember(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
+    entity = 'member'
+
     support_status = support.SupportStatus(
-        support.DEPRECATED, DEPR_MSG, version='7.0.0',
-        previous_status=support.SupportStatus(version='2014.1')
+        status=support.HIDDEN,
+        version='9.0.0',
+        message=_('Use LBaaS V2 instead.'),
+        previous_status=support.SupportStatus(
+            status=support.DEPRECATED,
+            message=DEPR_MSG,
+            version='7.0.0',
+            previous_status=support.SupportStatus(version='2014.1')
+        )
     )
 
     PROPERTIES = (
@@ -710,9 +730,6 @@ class PoolMember(neutron.NeutronResource):
         member = self.client().create_member({'member': params})['member']
         self.resource_id_set(member['id'])
 
-    def _show_resource(self):
-        return self.client().show_member(self.resource_id)['member']
-
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         if prop_diff:
             self.client().update_member(
@@ -737,8 +754,15 @@ class LoadBalancer(resource.Resource):
     required_service_extension = 'lbaas'
 
     support_status = support.SupportStatus(
-        support.DEPRECATED, DEPR_MSG, version='7.0.0',
-        previous_status=support.SupportStatus(version='2014.1')
+        status=support.HIDDEN,
+        version='9.0.0',
+        message=_('Use LBaaS V2 instead.'),
+        previous_status=support.SupportStatus(
+            status=support.DEPRECATED,
+            message=DEPR_MSG,
+            version='7.0.0',
+            previous_status=support.SupportStatus(version='2014.1')
+        )
     )
 
     PROPERTIES = (
