@@ -17,6 +17,7 @@ from heat.engine import constraints
 from heat.engine import properties
 from heat.engine.resources.openstack.neutron import neutron
 from heat.engine import support
+from heat.engine import translation
 
 
 class Net(neutron.NeutronResource):
@@ -26,22 +27,25 @@ class Net(neutron.NeutronResource):
     reserved to the tenant who created it, unless the network has been
     explicitly configured to be shared.
     """
+
+    entity = 'network'
+
     PROPERTIES = (
         NAME, VALUE_SPECS, ADMIN_STATE_UP, TENANT_ID, SHARED,
         DHCP_AGENT_IDS, PORT_SECURITY_ENABLED, QOS_POLICY,
-        DNS_DOMAIN,
+        DNS_DOMAIN, TAGS,
     ) = (
         'name', 'value_specs', 'admin_state_up', 'tenant_id', 'shared',
         'dhcp_agent_ids', 'port_security_enabled', 'qos_policy',
-        'dns_domain',
+        'dns_domain', 'tags',
     )
 
     ATTRIBUTES = (
         STATUS, NAME_ATTR, SUBNETS, ADMIN_STATE_UP_ATTR, TENANT_ID_ATTR,
-        PORT_SECURITY_ENABLED_ATTR, MTU_ATTR, QOS_POLICY_ATTR,
+        PORT_SECURITY_ENABLED_ATTR, MTU_ATTR, QOS_POLICY_ATTR, L2_ADJACENCY
     ) = (
         "status", "name", "subnets", "admin_state_up", "tenant_id",
-        "port_security_enabled", "mtu", 'qos_policy_id',
+        "port_security_enabled", "mtu", 'qos_policy_id', 'l2_adjacency'
     )
 
     properties_schema = {
@@ -112,6 +116,13 @@ class Net(neutron.NeutronResource):
             update_allowed=True,
             support_status=support.SupportStatus(version='7.0.0')
         ),
+        TAGS: properties.Schema(
+            properties.Schema.LIST,
+            _('The tags to be added to the network.'),
+            schema=properties.Schema(properties.Schema.STRING),
+            update_allowed=True,
+            support_status=support.SupportStatus(version='9.0.0')
+        ),
     }
 
     attributes_schema = {
@@ -150,8 +161,22 @@ class Net(neutron.NeutronResource):
             type=attributes.Schema.STRING,
             support_status=support.SupportStatus(version='6.0.0'),
         ),
+        L2_ADJACENCY: attributes.Schema(
+            _("A boolean value for L2 adjacency, True means that you can "
+              "expect L2 connectivity throughout the Network."),
+            type=attributes.Schema.BOOLEAN,
+            support_status=support.SupportStatus(version='9.0.0'),
+        ),
     }
 
+    def translation_rules(self, properties):
+        return [translation.TranslationRule(
+            properties,
+            translation.TranslationRule.RESOLVE,
+            [self.QOS_POLICY],
+            client_plugin=self.client_plugin(),
+            finder='get_qos_policy_id')]
+
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
@@ -159,9 +184,9 @@ class Net(neutron.NeutronResource):
 
         dhcp_agent_ids = props.pop(self.DHCP_AGENT_IDS, None)
         qos_policy = props.pop(self.QOS_POLICY, None)
+        tags = props.pop(self.TAGS, [])
         if qos_policy:
-            props['qos_policy_id'] = self.client_plugin().get_qos_policy_id(
-                qos_policy)
+            props['qos_policy_id'] = qos_policy
 
         net = self.client().create_network({'network': props})['network']
         self.resource_id_set(net['id'])
@@ -169,12 +194,12 @@ class Net(neutron.NeutronResource):
         if dhcp_agent_ids:
             self._replace_dhcp_agents(dhcp_agent_ids)
 
-    def _show_resource(self):
-        return self.client().show_network(
-            self.resource_id)['network']
+        if tags:
+            self.set_tags(tags)
 
     def check_create_complete(self, *args):
         attributes = self._show_resource()
+        self._store_config_default_properties(attributes)
         return self.is_built(attributes)
 
     def handle_delete(self):
@@ -189,13 +214,15 @@ class Net(neutron.NeutronResource):
         if prop_diff:
             self.prepare_update_properties(prop_diff)
             if self.DHCP_AGENT_IDS in prop_diff:
-                dhcp_agent_ids = prop_diff.pop(self.DHCP_AGENT_IDS, [])
+                dhcp_agent_ids = prop_diff.pop(self.DHCP_AGENT_IDS) or []
                 self._replace_dhcp_agents(dhcp_agent_ids)
             if self.QOS_POLICY in prop_diff:
                 qos_policy = prop_diff.pop(self.QOS_POLICY)
                 prop_diff[
                     'qos_policy_id'] = self.client_plugin().get_qos_policy_id(
                     qos_policy) if qos_policy else None
+            if self.TAGS in prop_diff:
+                self.set_tags(prop_diff.pop(self.TAGS))
         if prop_diff:
             self.client().update_network(self.resource_id,
                                          {'network': prop_diff})
@@ -231,6 +258,21 @@ class Net(neutron.NeutronResource):
                         self.client_plugin().is_not_found(ex)):
                     raise
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        result = super(Net, self).parse_live_resource_data(
+            resource_properties, resource_data)
+        result.pop(self.SHARED)
+        result[self.QOS_POLICY] = resource_data.get('qos_policy_id')
+        try:
+            dhcp = self.client().list_dhcp_agent_hosting_networks(
+                self.resource_id)
+            dhcp_agents = set([agent['id'] for agent in dhcp['agents']])
+            result.update({self.DHCP_AGENT_IDS: list(dhcp_agents)})
+        except self.client_plugin().exceptions.Forbidden:
+            # Just don't add dhcp_clients if we can't get values.
+            pass
+        return result
+
 
 def resource_mapping():
     return {
