@@ -33,12 +33,14 @@ class Router(neutron.NeutronResource):
 
     required_service_extension = 'router'
 
+    entity = 'router'
+
     PROPERTIES = (
         NAME, EXTERNAL_GATEWAY, VALUE_SPECS, ADMIN_STATE_UP,
-        L3_AGENT_ID, L3_AGENT_IDS, DISTRIBUTED, HA,
+        L3_AGENT_ID, L3_AGENT_IDS, DISTRIBUTED, HA, TAGS,
     ) = (
         'name', 'external_gateway_info', 'value_specs', 'admin_state_up',
-        'l3_agent_id', 'l3_agent_ids', 'distributed', 'ha'
+        'l3_agent_id', 'l3_agent_ids', 'distributed', 'ha', 'tags',
     )
 
     _EXTERNAL_GATEWAY_KEYS = (
@@ -171,6 +173,13 @@ class Router(neutron.NeutronResource):
               'do not support distributed and ha at the same time.'),
             support_status=support.SupportStatus(version='2015.1')
         ),
+        TAGS: properties.Schema(
+            properties.Schema.LIST,
+            _('The tags to be added to the router.'),
+            schema=properties.Schema(properties.Schema.STRING),
+            update_allowed=True,
+            support_status=support.SupportStatus(version='9.0.0')
+        ),
     }
 
     attributes_schema = {
@@ -295,16 +304,15 @@ class Router(neutron.NeutronResource):
             self.physical_resource_name())
         self._resolve_gateway(props)
         l3_agent_ids = self._get_l3_agent_list(props)
+        tags = props.pop(self.TAGS, [])
 
         router = self.client().create_router({'router': props})['router']
         self.resource_id_set(router['id'])
 
         if l3_agent_ids:
             self._replace_agent(l3_agent_ids)
-
-    def _show_resource(self):
-        return self.client().show_router(
-            self.resource_id)['router']
+        if tags:
+            self.set_tags(tags)
 
     def check_create_complete(self, *args):
         attributes = self._show_resource()
@@ -326,6 +334,10 @@ class Router(neutron.NeutronResource):
             l3_agent_ids = self._get_l3_agent_list(prop_diff)
             self._replace_agent(l3_agent_ids)
 
+        if self.TAGS in prop_diff:
+            tags = prop_diff.pop(self.TAGS)
+            self.set_tags(tags)
+
         if prop_diff:
             self.prepare_update_properties(prop_diff)
             self.client().update_router(
@@ -342,6 +354,27 @@ class Router(neutron.NeutronResource):
                 self.client().add_router_to_l3_agent(
                     l3_agent_id, {'router_id': self.resource_id})
 
+    def parse_live_resource_data(self, resource_properties, resource_data):
+        result = super(Router, self).parse_live_resource_data(
+            resource_properties, resource_data)
+
+        try:
+            ret = self.client().list_l3_agent_hosting_routers(self.resource_id)
+            if ret:
+                result[self.L3_AGENT_IDS] = list(
+                    agent['id'] for agent in ret['agents'])
+        except self.client_plugin().exceptions.Forbidden:
+            # Just pass if forbidden
+            pass
+
+        gateway = resource_data.get(self.EXTERNAL_GATEWAY)
+        if gateway is not None:
+            result[self.EXTERNAL_GATEWAY] = {
+                self.EXTERNAL_GATEWAY_NETWORK: gateway.get('network_id'),
+                self.EXTERNAL_GATEWAY_ENABLE_SNAT: gateway.get('enable_snat')
+            }
+        return result
+
 
 class RouterInterface(neutron.NeutronResource):
     """A resource for managing Neutron router interfaces.
@@ -553,9 +586,14 @@ class RouterGateway(neutron.NeutronResource):
         NETWORK_ID: properties.Schema(
             properties.Schema.STRING,
             support_status=support.SupportStatus(
-                status=support.DEPRECATED,
+                status=support.HIDDEN,
                 message=_('Use property %s.') % NETWORK,
-                version='2014.2'),
+                version='9.0.0',
+                previous_status=support.SupportStatus(
+                    status=support.DEPRECATED,
+                    version='2014.2'
+                )
+            ),
             constraints=[
                 constraints.CustomConstraint('neutron.network')
             ],
