@@ -29,6 +29,8 @@ class VPNService(neutron.NeutronResource):
 
     required_service_extension = 'vpnaas'
 
+    entity = 'vpnservice'
+
     PROPERTIES = (
         NAME, DESCRIPTION, ADMIN_STATE_UP,
         SUBNET_ID, SUBNET, ROUTER_ID, ROUTER
@@ -155,23 +157,37 @@ class VPNService(neutron.NeutronResource):
                 [self.SUBNET],
                 value_path=[self.SUBNET_ID]
             ),
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.SUBNET],
+                client_plugin=self.client_plugin(),
+                finder='find_resourceid_by_name_or_id',
+                entity='subnet'
+            ),
             translation.TranslationRule(
                 props,
                 translation.TranslationRule.REPLACE,
                 [self.ROUTER],
                 value_path=[self.ROUTER_ID]
-            )
-        ]
+            ),
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.ROUTER],
+                client_plugin=self.client_plugin(),
+                finder='find_resourceid_by_name_or_id',
+                entity='router'
+            ),
 
-    def _show_resource(self):
-        return self.client().show_vpnservice(self.resource_id)['vpnservice']
+        ]
 
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
             self.physical_resource_name())
-        self.client_plugin().resolve_subnet(props, self.SUBNET, 'subnet_id')
-        self.client_plugin().resolve_router(props, self.ROUTER, 'router_id')
+        props['subnet_id'] = props.pop(self.SUBNET)
+        props['router_id'] = props.pop(self.ROUTER)
         vpnservice = self.client().create_vpnservice({'vpnservice': props})[
             'vpnservice']
         self.resource_id_set(vpnservice['id'])
@@ -200,6 +216,8 @@ class IPsecSiteConnection(neutron.NeutronResource):
 
     required_service_extension = 'vpnaas'
 
+    entity = 'ipsec_site_connection'
+
     PROPERTIES = (
         NAME, DESCRIPTION, PEER_ADDRESS, PEER_ID, PEER_CIDRS, MTU,
         DPD, PSK, INITIATOR, ADMIN_STATE_UP, IKEPOLICY_ID,
@@ -413,10 +431,6 @@ class IPsecSiteConnection(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_ipsec_site_connection(self.resource_id)[
-            'ipsec_site_connection']
-
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
@@ -442,13 +456,15 @@ class IPsecSiteConnection(neutron.NeutronResource):
 class IKEPolicy(neutron.NeutronResource):
     """A resource for IKE policy in Neutron.
 
-    The Internet Key Exchange policy identifyies the authentication and
+    The Internet Key Exchange policy identifies the authentication and
     encryption algorithm used during phase one and phase two negotiation of a
     VPN connection.
     """
 
     required_service_extension = 'vpnaas'
 
+    entity = 'ikepolicy'
+
     PROPERTIES = (
         NAME, DESCRIPTION, AUTH_ALGORITHM, ENCRYPTION_ALGORITHM,
         PHASE1_NEGOTIATION_MODE, LIFETIME, PFS, IKE_VERSION,
@@ -489,8 +505,10 @@ class IKEPolicy(neutron.NeutronResource):
             _('Authentication hash algorithm for the ike policy.'),
             default='sha1',
             constraints=[
-                constraints.AllowedValues(['sha1']),
-            ]
+                constraints.AllowedValues(['sha1', 'sha256',
+                                           'sha384', 'sha512']),
+            ],
+            update_allowed=True
         ),
         ENCRYPTION_ALGORITHM: properties.Schema(
             properties.Schema.STRING,
@@ -587,9 +605,6 @@ class IKEPolicy(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_ikepolicy(self.resource_id)['ikepolicy']
-
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
@@ -621,6 +636,8 @@ class IPsecPolicy(neutron.NeutronResource):
 
     required_service_extension = 'vpnaas'
 
+    entity = 'ipsecpolicy'
+
     PROPERTIES = (
         NAME, DESCRIPTION, TRANSFORM_PROTOCOL, ENCAPSULATION_MODE,
         AUTH_ALGORITHM, ENCRYPTION_ALGORITHM, LIFETIME, PFS,
@@ -761,9 +778,6 @@ class IPsecPolicy(neutron.NeutronResource):
         ),
     }
 
-    def _show_resource(self):
-        return self.client().show_ipsecpolicy(self.resource_id)['ipsecpolicy']
-
     def handle_create(self):
         props = self.prepare_properties(
             self.properties,
