@@ -18,6 +18,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
 from heat.common import exception
+from heat.common import password_gen
 from heat.engine.clients import progress
 from heat.engine.resources import stack_user
 
@@ -66,6 +67,8 @@ class BaseServer(stack_user.StackUser):
         occ = meta['os-collect-config']
         collectors = list(self.default_collectors)
         occ['collectors'] = collectors
+        region_name = (self.context.region_name or
+                       cfg.CONF.region_name_for_services)
 
         # set existing values to None to override any boot-time config
         occ_keys = ('heat', 'zaqar', 'cfn', 'request')
@@ -84,7 +87,8 @@ class BaseServer(stack_user.StackUser):
                 'auth_url': self.context.auth_url,
                 'project_id': self.stack.stack_user_project_id,
                 'stack_id': self.stack.identifier().stack_path(),
-                'resource_name': self.name}})
+                'resource_name': self.name,
+                'region_name': region_name}})
             collectors.append('heat')
 
         elif self.transport_zaqar_message(props):
@@ -94,7 +98,8 @@ class BaseServer(stack_user.StackUser):
                 'password': self.password,
                 'auth_url': self.context.auth_url,
                 'project_id': self.stack.stack_user_project_id,
-                'queue_id': queue_id}})
+                'queue_id': queue_id,
+                'region_name': region_name}})
             collectors.append('zaqar')
 
         elif self.transport_poll_server_cfn(props):
@@ -151,7 +156,7 @@ class BaseServer(stack_user.StackUser):
         elif (self.transport_poll_server_heat(props) or
               self.transport_zaqar_message(props)):
             if self.password is None:
-                self.password = uuid.uuid4().hex
+                self.password = password_gen.generate_openstack_password()
             self._create_user()
 
         self._register_access_key()
