@@ -15,14 +15,14 @@
 
 """Stack object."""
 
-import six
-
 from oslo_versionedobjects import base
 from oslo_versionedobjects import fields
+import six
 
 from heat.common import exception
 from heat.common.i18n import _
-from heat.db import api as db_api
+from heat.common import identifier
+from heat.db.sqlalchemy import api as db_api
 from heat.objects import base as heat_base
 from heat.objects import fields as heat_fields
 from heat.objects import raw_template
@@ -59,7 +59,6 @@ class Stack(
         'current_deps': heat_fields.JsonField(),
         'prev_raw_template_id': fields.IntegerField(),
         'prev_raw_template': fields.ObjectField('RawTemplate'),
-        'tags': fields.ObjectField('StackTagList'),
         'parent_resource_name': fields.StringField(nullable=True),
     }
 
@@ -67,12 +66,15 @@ class Stack(
     def _from_db_object(context, stack, db_stack):
         for field in stack.fields:
             if field == 'raw_template':
-                stack['raw_template'] = (
-                    raw_template.RawTemplate.get_by_id(
-                        context, db_stack['raw_template_id']))
-            elif field == 'tags':
-                stack['tags'] = stack_tag.StackTagList.from_db_object(
-                    context, db_stack.get(field))
+                raw_template_obj = db_stack.__dict__.get('raw_template')
+                if raw_template_obj is not None:
+                    # Object is already lazy loaded
+                    raw_template_obj = (
+                        raw_template.RawTemplate.from_db_object(
+                            context,
+                            raw_template.RawTemplate(),
+                            raw_template_obj))
+                stack['raw_template'] = raw_template_obj
             else:
                 stack[field] = db_stack.__dict__.get(field)
         stack._context = context
@@ -112,8 +114,26 @@ class Stack(
         return stack
 
     @classmethod
-    def get_all(cls, context, *args, **kwargs):
-        db_stacks = db_api.stack_get_all(context, *args, **kwargs)
+    def get_all(cls, context, limit=None, sort_keys=None, marker=None,
+                sort_dir=None, filters=None,
+                show_deleted=False, show_nested=False, show_hidden=False,
+                tags=None, tags_any=None, not_tags=None,
+                not_tags_any=None, eager_load=False):
+        db_stacks = db_api.stack_get_all(
+            context,
+            limit=limit,
+            sort_keys=sort_keys,
+            marker=marker,
+            sort_dir=sort_dir,
+            filters=filters,
+            show_deleted=show_deleted,
+            show_nested=show_nested,
+            show_hidden=show_hidden,
+            tags=tags,
+            tags_any=tags_any,
+            not_tags=not_tags,
+            not_tags_any=not_tags_any,
+            eager_load=eager_load)
         for db_stack in db_stacks:
             try:
                 yield cls._from_db_object(context, cls(context), db_stack)
@@ -129,6 +149,16 @@ class Stack(
             except exception.NotFound:
                 pass
 
+    @classmethod
+    def get_all_by_root_owner_id(cls, context, root_owner_id):
+        db_stacks = db_api.stack_get_all_by_root_owner_id(context,
+                                                          root_owner_id)
+        for db_stack in db_stacks:
+            try:
+                yield cls._from_db_object(context, cls(context), db_stack)
+            except exception.NotFound:
+                pass
+
     @classmethod
     def count_all(cls, context, **kwargs):
         return db_api.stack_count_all(context, **kwargs)
@@ -190,6 +220,9 @@ class Stack(
         self.refresh()  # to make test object comparison work well
         return super(Stack, self).__eq__(another)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def refresh(self):
         db_stack = db_api.stack_get(
             self._context, self.id, show_deleted=True)
@@ -210,3 +243,11 @@ class Stack(
     def get_status(cls, context, stack_id):
         """Return action and status for the given stack."""
         return db_api.stack_get_status(context, stack_id)
+
+    def identifier(self):
+        """Return an identifier for this stack."""
+        return identifier.HeatIdentifier(self.tenant, self.name, self.id)
+
+    @property
+    def tags(self):
+        return stack_tag.StackTagList.get(self._context, self.id)
