@@ -13,21 +13,21 @@
 # under the License.
 
 
-"""
-UserCreds object
-"""
-
+"""UserCreds object."""
 
 from oslo_versionedobjects import base
 from oslo_versionedobjects import fields
 
-from heat.db import api as db_api
+from heat.db.sqlalchemy import api as db_api
+from heat.objects import base as heat_base
 
 
 @base.VersionedObjectRegistry.register
-class UserCreds(base.VersionedObject,
-                base.VersionedObjectDictCompat,
-                base.ComparableVersionedObject):
+class UserCreds(
+        heat_base.HeatObject,
+        base.VersionedObjectDictCompat,
+        base.ComparableVersionedObject,
+):
     fields = {
         'id': fields.StringField(),
         'created_at': fields.DateTimeField(read_only=True),
@@ -67,7 +67,7 @@ class UserCreds(base.VersionedObject,
         db_api.user_creds_delete(context, user_creds_id)
 
     @classmethod
-    def get_by_id(cls, context_id):
-        user_creds_db = db_api.user_creds_get(context_id)
+    def get_by_id(cls, context, user_creds_id):
+        user_creds_db = db_api.user_creds_get(context, user_creds_id)
         user_creds = cls._from_db_object(cls(), user_creds_db)
         return user_creds
