@@ -11,10 +11,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import datetime
-
 import mock
-from oslo_utils import timeutils
 import six
 
 from heat.common import exception
@@ -69,8 +66,7 @@ class TestAutoScalingPolicy(common.HeatTestCase):
     def test_scaling_policy_bad_group(self):
         t = template_format.parse(inline_templates.as_heat_template_bad_group)
         stack = utils.parse_stack(t)
-        up_policy = self.create_scaling_policy(t, stack,
-                                               'my-policy')
+        up_policy = self.create_scaling_policy(t, stack, 'my-policy')
 
         ex = self.assertRaises(exception.ResourceFailure, up_policy.signal)
         self.assertIn('Alarm my-policy could '
@@ -79,33 +75,28 @@ class TestAutoScalingPolicy(common.HeatTestCase):
     def test_scaling_policy_adjust_no_action(self):
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
-        up_policy = self.create_scaling_policy(t, stack,
-                                               'my-policy')
+        up_policy = self.create_scaling_policy(t, stack, 'my-policy')
         group = stack['my-group']
         self.patchobject(group, 'adjust',
                          side_effect=resource.NoActionRequired())
-        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
-        with mock.patch.object(up_policy,
-                               '_check_scaling_allowed') as mock_isa:
-            self.assertRaises(resource.NoActionRequired,
-                              up_policy.handle_signal)
-            mock_isa.assert_called_once_with()
-            mock_fin_scaling.assert_called_once_with('change_in_capacity : 1',
-                                                     size_changed=False)
+        self.assertRaises(resource.NoActionRequired,
+                          up_policy.handle_signal)
 
     def test_scaling_policy_adjust_size_changed(self):
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
-        up_policy = self.create_scaling_policy(t, stack,
-                                               'my-policy')
+        up_policy = self.create_scaling_policy(t, stack, 'my-policy')
         group = stack['my-group']
-        self.patchobject(group, 'adjust')
-        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
-        with mock.patch.object(up_policy,
+        self.patchobject(group, 'resize')
+        self.patchobject(group, '_lb_reload')
+        mock_fin_scaling = self.patchobject(group, '_finished_scaling')
+
+        with mock.patch.object(group,
                                '_check_scaling_allowed') as mock_isa:
             self.assertIsNone(up_policy.handle_signal())
-            mock_isa.assert_called_once_with()
-            mock_fin_scaling.assert_called_once_with('change_in_capacity : 1',
+            mock_isa.assert_called_once_with(60)
+            mock_fin_scaling.assert_called_once_with(60,
+                                                     'change_in_capacity : 1',
                                                      size_changed=True)
 
     def test_scaling_policy_cooldown_toosoon(self):
@@ -115,39 +106,27 @@ class TestAutoScalingPolicy(common.HeatTestCase):
         group = stack['my-group']
         test = {'current': 'alarm'}
 
-        with mock.patch.object(group, 'adjust',
-                               side_effect=AssertionError) as dont_call:
-            with mock.patch.object(
-                    pol, '_check_scaling_allowed',
-                    side_effect=resource.NoActionRequired) as mock_cip:
-                self.assertRaises(resource.NoActionRequired,
-                                  pol.handle_signal, details=test)
-                mock_cip.assert_called_once_with()
-            self.assertEqual([], dont_call.call_args_list)
-
-    def test_policy_metadata_reset(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-        metadata = {'scaling_in_progress': True}
-        pol.metadata_set(metadata)
-        pol.handle_metadata_reset()
-
-        new_metadata = pol.metadata_get()
-        self.assertEqual({'scaling_in_progress': False}, new_metadata)
+        with mock.patch.object(
+                group, '_check_scaling_allowed',
+                side_effect=resource.NoActionRequired) as mock_cip:
+            self.assertRaises(resource.NoActionRequired,
+                              pol.handle_signal, details=test)
+            mock_cip.assert_called_once_with(60)
 
     def test_scaling_policy_cooldown_ok(self):
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
         pol = self.create_scaling_policy(t, stack, 'my-policy')
+        group = stack['my-group']
         test = {'current': 'alarm'}
+        self.patchobject(group, '_finished_scaling')
+        self.patchobject(group, '_lb_reload')
+        mock_resize = self.patchobject(group, 'resize')
 
-        group = self.patchobject(pol.stack, 'resource_by_refid').return_value
-        group.name = 'fluffy'
-        with mock.patch.object(pol, '_check_scaling_allowed') as mock_isa:
+        with mock.patch.object(group, '_check_scaling_allowed') as mock_isa:
             pol.handle_signal(details=test)
-            mock_isa.assert_called_once_with()
-        group.adjust.assert_called_once_with(1, 'change_in_capacity', None)
+            mock_isa.assert_called_once_with(60)
+        mock_resize.assert_called_once_with(1)
 
     def test_scaling_policy_refid(self):
         t = template_format.parse(as_template)
@@ -170,111 +149,6 @@ class TestAutoScalingPolicy(common.HeatTestCase):
         self.assertEqual('convg_xyz', rsrc.FnGetRefId())
 
 
-class TestCooldownMixin(common.HeatTestCase):
-    def create_scaling_policy(self, t, stack, resource_name):
-        rsrc = stack[resource_name]
-        self.assertIsNone(rsrc.validate())
-        scheduler.TaskRunner(rsrc.create)()
-        self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
-        return rsrc
-
-    def test_cooldown_is_in_progress_toosoon(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        now = timeutils.utcnow()
-        previous_meta = {'cooldown': {
-            now.isoformat(): 'change_in_capacity : 1'}}
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        ex = self.assertRaises(resource.NoActionRequired,
-                               pol._check_scaling_allowed)
-        self.assertIn('due to cooldown', six.text_type(ex))
-
-    def test_cooldown_is_in_progress_scaling_unfinished(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        previous_meta = {'scaling_in_progress': True}
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        ex = self.assertRaises(resource.NoActionRequired,
-                               pol._check_scaling_allowed)
-        self.assertIn('due to scaling activity', six.text_type(ex))
-
-    def test_cooldown_not_in_progress(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        awhile_ago = timeutils.utcnow() - datetime.timedelta(seconds=100)
-        previous_meta = {
-            'cooldown': {
-                awhile_ago.isoformat(): 'change_in_capacity : 1'
-            },
-            'scaling_in_progress': False
-        }
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertIsNone(pol._check_scaling_allowed())
-
-    def test_scaling_policy_cooldown_zero(self):
-        t = template_format.parse(as_template)
-
-        # Create the scaling policy (with cooldown=0) and scale up one
-        properties = t['resources']['my-policy']['properties']
-        properties['cooldown'] = '0'
-
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        now = timeutils.utcnow()
-        previous_meta = {'cooldown': {
-            now.isoformat(): 'change_in_capacity : 1'}}
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertIsNone(pol._check_scaling_allowed())
-
-    def test_scaling_policy_cooldown_none(self):
-        t = template_format.parse(as_template)
-
-        # Create the scaling policy no cooldown property, should behave the
-        # same as when cooldown==0
-        properties = t['resources']['my-policy']['properties']
-        del properties['cooldown']
-
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        now = timeutils.utcnow()
-        previous_meta = {'cooldown': {
-            now.isoformat(): 'change_in_capacity : 1'}}
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertIsNone(pol._check_scaling_allowed())
-
-    def test_no_cooldown_no_scaling_in_progress(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        # no cooldown entry in the metadata
-        previous_meta = {'scaling_in_progress': False}
-        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertIsNone(pol._check_scaling_allowed())
-
-    def test_metadata_is_written(self):
-        t = template_format.parse(as_template)
-        stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
-
-        nowish = timeutils.utcnow()
-        reason = 'cool as'
-        meta_set = self.patchobject(pol, 'metadata_set')
-        self.patchobject(timeutils, 'utcnow', return_value=nowish)
-        pol._finished_scaling(reason, size_changed=True)
-        meta_set.assert_called_once_with(
-            {'cooldown': {nowish.isoformat(): reason},
-             'scaling_in_progress': False})
-
-
 class ScalingPolicyAttrTest(common.HeatTestCase):
     def setUp(self):
         super(ScalingPolicyAttrTest, self).setUp()
