@@ -274,7 +274,7 @@ class s3Test(common.HeatTestCase):
         self.m.VerifyAll()
 
     def test_delete_conflict_empty(self):
-        cfg.CONF.set_override('action_retry_limit', 0, enforce_type=True)
+        cfg.CONF.set_override('action_retry_limit', 0)
         t = template_format.parse(swift_template)
         stack = utils.parse_stack(t)
 
