@@ -25,10 +25,12 @@ from heat.common import exception
 from heat.common import identifier
 from heat.common import template_format
 from heat.engine import environment
+from heat.engine import node_data
 from heat.engine.resources.aws.cfn import wait_condition_handle as aws_wch
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.engine import stack as parser
+from heat.engine import stk_defn
 from heat.engine import template as tmpl
 from heat.objects import resource as resource_objects
 from heat.tests import common
@@ -272,15 +274,15 @@ class WaitConditionTest(common.HeatTestCase):
         template = tmpl.Template(t)
         stack = parser.Stack(utils.dummy_context(), 'test', template,
                              cache_data={
-                                 'WaitHandle': {
+                                 'WaitHandle': node_data.NodeData.from_dict({
                                      'uuid': mock.ANY,
                                      'id': mock.ANY,
                                      'action': 'CREATE',
                                      'status': 'COMPLETE',
                                      'reference_id': 'http://convg_signed_url'
-                                 }})
+                                 })})
 
-        rsrc = stack['WaitHandle']
+        rsrc = stack.defn['WaitHandle']
         self.assertEqual('http://convg_signed_url', rsrc.FnGetRefId())
 
     def test_validate_handle_url_bad_stackid(self):
@@ -640,6 +642,8 @@ class WaitConditionUpdateTest(common.HeatTestCase):
                                                       rsrc.type(),
                                                       uprops)
 
+        stk_defn.update_resource_data(self.stack.defn, 'WaitHandle',
+                                      self.stack['WaitHandle'].node_data())
         updater = scheduler.TaskRunner(rsrc.update, update_snippet)
         updater()
 
