@@ -14,6 +14,8 @@
 
 import uuid
 
+from cinderclient import exceptions as cinder_exc
+from keystoneauth1 import exceptions as ks_exceptions
 import mock
 
 from heat.common import exception
@@ -31,7 +33,7 @@ class CinderClientPluginTest(common.HeatTestCase):
         con = utils.dummy_context()
         c = con.clients
         self.cinder_plugin = c.client_plugin('cinder')
-        self.cinder_plugin._client = self.cinder_client
+        self.cinder_plugin.client = lambda: self.cinder_client
 
     def test_get_volume(self):
         """Tests the get_volume function."""
@@ -132,3 +134,73 @@ class VolumeBackupConstraintTest(common.HeatTestCase):
         ex = exception.EntityNotFound(entity='Volume backup', name='bar')
         self.mock_get_volume_backup.side_effect = ex
         self.assertFalse(self.constraint.validate("bar", self.ctx))
+
+
+class QoSSpecsConstraintTest(common.HeatTestCase):
+
+    def setUp(self):
+        super(QoSSpecsConstraintTest, self).setUp()
+        self.ctx = utils.dummy_context()
+        self.mock_get_qos_specs = mock.Mock()
+        self.ctx.clients.client_plugin(
+            'cinder').get_qos_specs = self.mock_get_qos_specs
+        self.constraint = cinder.QoSSpecsConstraint()
+
+    def test_validation(self):
+        self.mock_get_qos_specs.return_value = None
+        self.assertTrue(self.constraint.validate("foo", self.ctx))
+
+    def test_validation_error(self):
+        self.mock_get_qos_specs.side_effect = cinder_exc.NotFound(404)
+        self.assertFalse(self.constraint.validate("bar", self.ctx))
+
+
+class CinderClientAPIVersionTest(common.HeatTestCase):
+
+    def test_cinder_api_v3(self):
+        ctx = utils.dummy_context()
+        self.patchobject(ctx.keystone_session, 'get_endpoint')
+        client = ctx.clients.client('cinder')
+        self.assertEqual('3.0', client.version)
+
+    def test_cinder_api_v2(self):
+        ctx = utils.dummy_context()
+        self.patchobject(ctx.keystone_session, 'get_endpoint',
+                         side_effect=[ks_exceptions.EndpointNotFound,
+                                      None])
+        client = ctx.clients.client('cinder')
+        self.assertEqual('2.0', client.version)
+
+    def test_cinder_api_not_supported(self):
+        ctx = utils.dummy_context()
+        self.patchobject(ctx.keystone_session, 'get_endpoint',
+                         side_effect=[ks_exceptions.EndpointNotFound,
+                                      ks_exceptions.EndpointNotFound])
+        self.assertRaises(exception.Error, ctx.clients.client, 'cinder')
+
+
+class CinderClientPluginExtensionsTest(CinderClientPluginTest):
+    """Tests for extensions in cinderclient."""
+
+    def test_has_no_extensions(self):
+        self.cinder_client.list_extensions.show_all.return_value = []
+        self.assertFalse(self.cinder_plugin.has_extension(
+            "encryption"))
+
+    def test_has_no_interface_extensions(self):
+        mock_extension = mock.Mock()
+        p = mock.PropertyMock(return_value='os-xxxx')
+        type(mock_extension).alias = p
+        self.cinder_client.list_extensions.show_all.return_value = [
+            mock_extension]
+        self.assertFalse(self.cinder_plugin.has_extension(
+            "encryption"))
+
+    def test_has_os_interface_extension(self):
+        mock_extension = mock.Mock()
+        p = mock.PropertyMock(return_value='encryption')
+        type(mock_extension).alias = p
+        self.cinder_client.list_extensions.show_all.return_value = [
+            mock_extension]
+        self.assertTrue(self.cinder_plugin.has_extension(
+            "encryption"))
