@@ -36,6 +36,7 @@ from heat.common import exception
 from heat.engine import clients
 from heat.engine.clients import client_exception
 from heat.engine.clients import client_plugin
+from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
 from heat.tests import common
 from heat.tests import fakes
 from heat.tests.openstack.nova import fakes as fakes_nova
@@ -99,26 +100,6 @@ class ClientsTest(common.HeatTestCase):
         obj = self._client_cfn_url()
         self.assertEqual("http://0.0.0.0:8000/v1/", obj.get_heat_cfn_url())
 
-    def test_clients_get_watch_server_url(self):
-        obj = self._client_cfn_url()
-        self.assertEqual("http://0.0.0.0:8003/v1/",
-                         obj.get_watch_server_url())
-
-    def test_clients_get_watch_server_url_ipv6(self):
-        obj = self._client_cfn_url(use_ipv6=True)
-        self.assertEqual("http://[::1]:8003/v1/",
-                         obj.get_watch_server_url())
-
-    def test_clients_get_watch_server_url_use_uwsgi_ipv6(self):
-        obj = self._client_cfn_url(use_uwsgi=True, use_ipv6=True)
-        self.assertEqual("http://[::1]/heat-api-cloudwatch/v1/",
-                         obj.get_watch_server_url())
-
-    def test_clients_get_watch_server_url_use_uwsgi(self):
-        obj = self._client_cfn_url(use_uwsgi=True)
-        self.assertEqual("http://0.0.0.0/heat-api-cloudwatch/v1/",
-                         obj.get_watch_server_url())
-
     def test_clients_get_heat_cfn_metadata_url(self):
         obj = self._client_cfn_url()
         self.assertEqual("http://0.0.0.0:8000/v1/",
@@ -257,7 +238,7 @@ class ClientPluginTest(common.HeatTestCase):
 
     @mock.patch.object(generic, "Token", name="v3_token")
     def test_get_missing_service_catalog(self, mock_v3):
-        class FakeKeystone(fakes.FakeKeystoneClient):
+        class FakeKeystone(fake_ks.FakeKeystoneClient):
             def __init__(self):
                 super(FakeKeystone, self).__init__()
                 self.client = self
@@ -285,7 +266,7 @@ class ClientPluginTest(common.HeatTestCase):
 
     @mock.patch.object(generic, "Token", name="v3_token")
     def test_endpoint_not_found(self, mock_v3):
-        class FakeKeystone(fakes.FakeKeystoneClient):
+        class FakeKeystone(fake_ks.FakeKeystoneClient):
             def __init__(self):
                 super(FakeKeystone, self).__init__()
                 self.client = self
