@@ -14,6 +14,8 @@
 import mock
 import six
 
+import monascaclient
+
 from heat.common import exception as heat_exception
 from heat.engine.clients.os import monasca as client_plugin
 from heat.tests import common
@@ -47,6 +49,12 @@ class MonascaClientPluginTest(common.HeatTestCase):
         client = plugin.client()
         self.assertIsNotNone(client.metrics)
 
+    @mock.patch.object(monascaclient.client, '_session')
+    def test_client_uses_session(self, mock_session):
+        context = mock.MagicMock()
+        monasca_client = client_plugin.MonascaClientPlugin(context=context)
+        self.assertIsNotNone(monasca_client._create())
+
 
 class MonascaClientPluginNotificationTest(common.HeatTestCase):
 
