@@ -20,7 +20,6 @@ from novaclient import client as nc
 from novaclient import exceptions as nova_exceptions
 from oslo_config import cfg
 from oslo_serialization import jsonutils as json
-from oslo_utils import encodeutils
 import requests
 import six
 
@@ -97,7 +96,7 @@ class NovaClientPluginTest(NovaClientPluginTestCase):
         self.assertEqual(expected, observed)
 
     def test_find_flavor_by_name_or_id(self):
-        """Tests the get_flavor_id function."""
+        """Tests the find_flavor_by_name_or_id function."""
         flav_id = str(uuid.uuid4())
         flav_name = 'X-Large'
         my_flavor = mock.MagicMock()
@@ -176,57 +175,6 @@ class NovaClientPluginTest(NovaClientPluginTestCase):
                  mock.call('idontexist')]
         self.nova_client.servers.get.assert_has_calls(calls)
 
-    def test_get_network_id_by_label(self):
-        """Tests the get_net_id_by_label function."""
-        net = mock.MagicMock()
-        net.id = str(uuid.uuid4())
-        self.nova_client.networks.find.side_effect = [
-            net, nova_exceptions.NotFound(404),
-            nova_exceptions.NoUniqueMatch()]
-        self.assertEqual(net.id,
-                         self.nova_plugin.get_net_id_by_label('net_label'))
-
-        exc = self.assertRaises(
-            exception.EntityNotFound,
-            self.nova_plugin.get_net_id_by_label, 'idontexist')
-        expected = 'The Nova network (idontexist) could not be found'
-        self.assertIn(expected, six.text_type(exc))
-        exc = self.assertRaises(
-            exception.PhysicalResourceNameAmbiguity,
-            self.nova_plugin.get_net_id_by_label, 'notUnique')
-        expected = ('Multiple physical resources were found '
-                    'with name (notUnique)')
-        self.assertIn(expected, six.text_type(exc))
-        calls = [mock.call(label='net_label'),
-                 mock.call(label='idontexist'),
-                 mock.call(label='notUnique')]
-        self.nova_client.networks.find.assert_has_calls(calls)
-
-    def test_get_nova_network_id(self):
-        """Tests the get_nova_network_id function."""
-        net = mock.MagicMock()
-        net.id = str(uuid.uuid4())
-        not_existent_net_id = str(uuid.uuid4())
-        self.nova_client.networks.get.side_effect = [
-            net, nova_exceptions.NotFound(404)]
-        self.nova_client.networks.find.side_effect = [
-            nova_exceptions.NotFound(404)]
-
-        self.assertEqual(net.id,
-                         self.nova_plugin.get_nova_network_id(net.id))
-        exc = self.assertRaises(
-            exception.EntityNotFound,
-            self.nova_plugin.get_nova_network_id, not_existent_net_id)
-        expected = ('The Nova network (%s) could not be found' %
-                    not_existent_net_id)
-        self.assertIn(expected, six.text_type(exc))
-
-        calls = [mock.call(net.id),
-                 mock.call(not_existent_net_id)]
-        self.nova_client.networks.get.assert_has_calls(calls)
-        self.nova_client.networks.find.assert_called_once_with(
-            label=not_existent_net_id)
-
     def test_get_status(self):
         server = self.m.CreateMockAnything()
         server.status = 'ACTIVE'
@@ -414,30 +362,23 @@ class NovaClientPluginUserdataTest(NovaClientPluginTestCase):
     def test_build_userdata(self):
         """Tests the build_userdata function."""
         cfg.CONF.set_override('heat_metadata_server_url',
-                              'http://server.test:123', enforce_type=True)
-        cfg.CONF.set_override('heat_watch_server_url',
-                              'http://server.test:345', enforce_type=True)
-        cfg.CONF.set_override('instance_connection_is_secure',
-                              False, enforce_type=True)
+                              'http://server.test:123')
+        cfg.CONF.set_override('instance_connection_is_secure', False)
         cfg.CONF.set_override(
-            'instance_connection_https_validate_certificates', False,
-            enforce_type=True)
+            'instance_connection_https_validate_certificates', False)
         data = self.nova_plugin.build_userdata({})
         self.assertIn("Content-Type: text/cloud-config;", data)
         self.assertIn("Content-Type: text/cloud-boothook;", data)
         self.assertIn("Content-Type: text/part-handler;", data)
         self.assertIn("Content-Type: text/x-cfninitdata;", data)
         self.assertIn("Content-Type: text/x-shellscript;", data)
-        self.assertIn("http://server.test:345", data)
         self.assertIn("http://server.test:123", data)
         self.assertIn("[Boto]", data)
 
     def test_build_userdata_without_instance_user(self):
         """Don't add a custom instance user when not requested."""
         cfg.CONF.set_override('heat_metadata_server_url',
-                              'http://server.test:123', enforce_type=True)
-        cfg.CONF.set_override('heat_watch_server_url',
-                              'http://server.test:345', enforce_type=True)
+                              'http://server.test:123')
         data = self.nova_plugin.build_userdata({}, instance_user=None)
         self.assertNotIn('user: ', data)
         self.assertNotIn('useradd', data)
@@ -446,9 +387,7 @@ class NovaClientPluginUserdataTest(NovaClientPluginTestCase):
     def test_build_userdata_with_instance_user(self):
         """Add a custom instance user."""
         cfg.CONF.set_override('heat_metadata_server_url',
-                              'http://server.test:123', enforce_type=True)
-        cfg.CONF.set_override('heat_watch_server_url',
-                              'http://server.test:345', enforce_type=True)
+                              'http://server.test:123')
         data = self.nova_plugin.build_userdata({}, instance_user='ec2-user')
         self.assertIn('user: ', data)
         self.assertIn('useradd', data)
@@ -558,39 +497,6 @@ class FlavorConstraintTest(common.HeatTestCase):
         self.assertEqual(2, client.flavors.find.call_count)
 
 
-class NetworkConstraintTest(common.HeatTestCase):
-
-    def test_validate(self):
-        client = fakes_nova.FakeClient()
-        self.stub_keystoneclient()
-        self.patchobject(nova.NovaClientPlugin, '_create', return_value=client)
-        client.networks = mock.Mock()
-
-        network = collections.namedtuple("Network", ['id', 'label'])
-        network.id = '7f47ff06-0353-4013-b814-123b70b1b27d'
-        network.label = 'foo'
-        client.networks.get.return_value = network
-
-        constraint = nova.NetworkConstraint()
-        ctx = utils.dummy_context()
-
-        self.assertTrue(constraint.validate(network.id, ctx))
-        client.networks.get.side_effect = nova_exceptions.NotFound('')
-        client.networks.find.return_value = network
-        self.assertTrue(constraint.validate(network.id, ctx))
-
-        client.networks.find.side_effect = nova_exceptions.NotFound('')
-        self.assertFalse(constraint.validate(network.id, ctx))
-
-        client.networks.find.side_effect = nova_exceptions.NoUniqueMatch()
-        self.assertFalse(constraint.validate(network.id, ctx))
-
-        network.id = 'nonuuid'
-        client.networks.find.return_value = network
-        client.networks.find.side_effect = None
-        self.assertTrue(constraint.validate(network.id, ctx))
-
-
 class HostConstraintTest(common.HeatTestCase):
 
     def setUp(self):
@@ -637,11 +543,12 @@ class KeypairConstraintTest(common.HeatTestCase):
 class ConsoleUrlsTest(common.HeatTestCase):
 
     scenarios = [
-        ('novnc', dict(console_type='novnc', srv_method='vnc')),
-        ('xvpvnc', dict(console_type='xvpvnc', srv_method='vnc')),
-        ('spice', dict(console_type='spice-html5', srv_method='spice')),
-        ('rdp', dict(console_type='rdp-html5', srv_method='rdp')),
-        ('serial', dict(console_type='serial', srv_method='serial')),
+        ('novnc', dict(console_type='novnc', res_obj=True)),
+        ('xvpvnc', dict(console_type='xvpvnc', res_obj=True)),
+        ('spice', dict(console_type='spice-html5', res_obj=True)),
+        ('rdp', dict(console_type='rdp-html5', res_obj=True)),
+        ('serial', dict(console_type='serial', res_obj=True)),
+        ('mks', dict(console_type='webmks', res_obj=False)),
     ]
 
     def setUp(self):
@@ -650,10 +557,14 @@ class ConsoleUrlsTest(common.HeatTestCase):
         con = utils.dummy_context()
         c = con.clients
         self.nova_plugin = c.client_plugin('nova')
-        self.nova_plugin.client = lambda: self.nova_client
+        self.patchobject(self.nova_plugin, 'client',
+                         return_value=self.nova_client)
         self.server = mock.Mock()
-        self.console_method = getattr(self.server,
-                                      'get_%s_console' % self.srv_method)
+        if self.res_obj:
+            self.console_method = getattr(self.server, 'get_console_url')
+        else:
+            self.console_method = getattr(self.nova_client.servers,
+                                          'get_console_url')
 
     def test_get_console_url(self):
         console = {
@@ -668,36 +579,48 @@ class ConsoleUrlsTest(common.HeatTestCase):
             self.console_type]
 
         self.assertEqual(console['console']['url'], console_url)
-        self.console_method.assert_called_once_with(self.console_type)
+        self._assert_console_method_called()
+
+    def _assert_console_method_called(self):
+        if self.console_type == 'webmks':
+            self.console_method.assert_called_once_with(self.server,
+                                                        self.console_type)
+        else:
+            self.console_method.assert_called_once_with(self.console_type)
+
+    def _test_get_console_url_tolerate_exception(self, msg):
+        console_url = self.nova_plugin.get_console_urls(self.server)[
+            self.console_type]
+
+        self._assert_console_method_called()
+        self.assertIn(msg, console_url)
 
     def test_get_console_url_tolerate_unavailable(self):
         msg = 'Unavailable console type %s.' % self.console_type
         self.console_method.side_effect = nova_exceptions.BadRequest(
             400, message=msg)
 
-        console_url = self.nova_plugin.get_console_urls(self.server)[
-            self.console_type]
+        self._test_get_console_url_tolerate_exception(msg)
 
-        self.console_method.assert_called_once_with(self.console_type)
-        self.assertEqual(msg, console_url)
+    def test_get_console_url_tolerate_unsupport(self):
+        msg = 'Unsupported console_type "%s"' % self.console_type
+        self.console_method.side_effect = (
+            nova_exceptions.UnsupportedConsoleType(
+                console_type=self.console_type))
 
-    def test_get_console_urls_reraises_other_400(self):
+        self._test_get_console_url_tolerate_exception(msg)
+
+    def test_get_console_urls_tolerate_other_400(self):
         exc = nova_exceptions.BadRequest
         self.console_method.side_effect = exc(400, message="spam")
 
-        urls = self.nova_plugin.get_console_urls(self.server)
-        e = self.assertRaises(exc, urls.__getitem__, self.console_type)
-        self.assertIn('spam', encodeutils.exception_to_unicode(e))
-        self.console_method.assert_called_once_with(self.console_type)
+        self._test_get_console_url_tolerate_exception('spam')
 
     def test_get_console_urls_reraises_other(self):
         exc = Exception
         self.console_method.side_effect = exc("spam")
 
-        urls = self.nova_plugin.get_console_urls(self.server)
-        e = self.assertRaises(exc, urls.__getitem__, self.console_type)
-        self.assertIn('spam', e.args)
-        self.console_method.assert_called_once_with(self.console_type)
+        self._test_get_console_url_tolerate_exception('spam')
 
 
 class NovaClientPluginExtensionsTest(NovaClientPluginTestCase):
