@@ -18,6 +18,7 @@ import six
 from heat.common import exception
 from heat.common import identifier
 from heat.engine.clients.os import keystone
+from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
 from heat.engine import dependencies
 from heat.engine import resource as res
 from heat.engine.resources.aws.ec2 import instance as ins
@@ -28,7 +29,6 @@ from heat.engine import template as templatem
 from heat.objects import stack as stack_object
 from heat.tests import common
 from heat.tests.engine import tools
-from heat.tests import fakes as test_fakes
 from heat.tests import generic_resource as generic_rsrc
 from heat.tests import utils
 
@@ -70,8 +70,8 @@ class StackResourcesServiceTest(common.HeatTestCase):
     def _test_describe_stack_resource(self, mock_load):
         mock_load.return_value = self.stack
 
-        # Patch _resolve_all_attributes or it tries to call novaclient
-        self.patchobject(res.Resource, '_resolve_all_attributes',
+        # Patch _resolve_any_attribute or it tries to call novaclient
+        self.patchobject(res.Resource, '_resolve_any_attribute',
                          return_value=None)
 
         r = self.eng.describe_stack_resource(self.ctx, self.stack.identifier(),
@@ -319,7 +319,7 @@ class StackResourcesServiceTest(common.HeatTestCase):
 
     def _stack_create(self, stack_name):
         self.patchobject(keystone.KeystoneClientPlugin, '_create',
-                         return_value=test_fakes.FakeKeystoneClient())
+                         return_value=fake_ks.FakeKeystoneClient())
 
         stk = tools.get_stack(stack_name, self.ctx, policy_template)
         stk.store()
@@ -457,7 +457,7 @@ class StackResourcesServiceTest(common.HeatTestCase):
                                           mock_update):
         # fake keystone client
         self.patchobject(keystone.KeystoneClientPlugin, '_create',
-                         return_value=test_fakes.FakeKeystoneClient())
+                         return_value=fake_ks.FakeKeystoneClient())
 
         stk = tools.get_stack('signal_reception', self.ctx, policy_template)
         self.stack = stk
@@ -485,7 +485,7 @@ class StackResourcesServiceTest(common.HeatTestCase):
                                              mock_update):
         # fake keystone client
         self.patchobject(keystone.KeystoneClientPlugin, '_create',
-                         return_value=test_fakes.FakeKeystoneClient())
+                         return_value=fake_ks.FakeKeystoneClient())
 
         stk = tools.get_stack('signal_reception', self.ctx, policy_template)
         self.stack = stk
