@@ -20,6 +20,7 @@ from heat.engine.clients.os import nova
 from heat.engine.resources.aws.ec2 import volume as aws_vol
 from heat.engine.resources.openstack.cinder import volume as os_vol
 from heat.engine import scheduler
+from heat.engine import stk_defn
 from heat.tests import common
 from heat.tests.openstack.nova import fakes as fakes_nova
 
@@ -64,19 +65,28 @@ class BaseVolumeTest(common.HeatTestCase):
         self.cinder_fc.volumes.get(fva.id).AndReturn(fv_ready)
         return fv_ready
 
-    def create_volume(self, t, stack, resource_name):
+    def get_volume(self, t, stack, resource_name):
         if self.use_cinder:
             Volume = os_vol.CinderVolume
         else:
             data = t['Resources'][resource_name]
             data['Properties']['AvailabilityZone'] = 'nova'
             Volume = aws_vol.Volume
-        rsrc = Volume(resource_name,
-                      stack.t.resource_definitions(stack)[resource_name],
-                      stack)
+        vol = Volume(resource_name,
+                     stack.defn.resource_definition(resource_name),
+                     stack)
+        return vol
+
+    def create_volume(self, t, stack, resource_name):
+        rsrc = self.get_volume(t, stack, resource_name)
+        if isinstance(rsrc, os_vol.CinderVolume):
+            self.patchobject(rsrc, '_store_config_default_properties')
+
         self.assertIsNone(rsrc.validate())
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
+        stk_defn.update_resource_data(stack.defn, resource_name,
+                                      rsrc.node_data())
         return rsrc
 
     def create_attachment(self, t, stack, resource_name):
@@ -84,13 +94,14 @@ class BaseVolumeTest(common.HeatTestCase):
             Attachment = os_vol.CinderVolumeAttachment
         else:
             Attachment = aws_vol.VolumeAttachment
-        resource_defns = stack.t.resource_definitions(stack)
         rsrc = Attachment(resource_name,
-                          resource_defns[resource_name],
+                          stack.defn.resource_definition(resource_name),
                           stack)
         self.assertIsNone(rsrc.validate())
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
+        stk_defn.update_resource_data(stack.defn, resource_name,
+                                      rsrc.node_data())
         return rsrc
 
 
@@ -99,7 +110,6 @@ class FakeVolume(object):
 
     def __init__(self, status, **attrs):
         self.status = status
-        self._info = {'volume': 'info'}
         for key, value in six.iteritems(attrs):
             setattr(self, key, value)
         if 'id' not in attrs:
