@@ -24,6 +24,7 @@ from heat.common.i18n import _
 from heat.common import template_format
 from heat.engine.clients.os import heat_plugin
 from heat.engine import environment
+from heat.engine import node_data
 from heat.engine import resource
 from heat.engine.resources.openstack.heat import remote_stack
 from heat.engine import rsrc_defn
@@ -130,7 +131,7 @@ class RemoteStackTest(tests_common.HeatTestCase):
         self.that_region = 'RegionTwo'
         self.bad_region = 'RegionNone'
 
-        cfg.CONF.set_override('action_retry_limit', 0, enforce_type=True)
+        cfg.CONF.set_override('action_retry_limit', 0)
         self.parent = None
         self.heat = None
         self.client_plugin = None
@@ -668,15 +669,15 @@ class RemoteStackTest(tests_common.HeatTestCase):
 
     def test_remote_stack_refid_convergence_cache_data(self):
         t = template_format.parse(parent_stack_template)
-        cache_data = {'remote_stack': {
+        cache_data = {'remote_stack': node_data.NodeData.from_dict({
             'uuid': mock.ANY,
             'id': mock.ANY,
             'action': 'CREATE',
             'status': 'COMPLETE',
             'reference_id': 'convg_xyz'
-        }}
+        })}
         stack = utils.parse_stack(t, cache_data=cache_data)
-        rsrc = stack['remote_stack']
+        rsrc = stack.defn['remote_stack']
         self.assertEqual('convg_xyz', rsrc.FnGetRefId())
 
     def test_update_in_check_failed_state(self):
