@@ -15,6 +15,7 @@ import copy
 
 import mock
 
+from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
 from heat.engine import constraints
 from heat.engine import properties
 from heat.engine import resource
@@ -22,7 +23,6 @@ from heat.engine.resources.openstack.keystone import endpoint
 from heat.engine import stack
 from heat.engine import template
 from heat.tests import common
-from heat.tests import fakes
 from heat.tests import utils
 
 keystone_endpoint_template = {
@@ -42,8 +42,6 @@ keystone_endpoint_template = {
     }
 }
 
-RESOURCE_TYPE = 'OS::Keystone::Endpoint'
-
 
 class KeystoneEndpointTest(common.HeatTestCase):
     def setUp(self):
@@ -54,7 +52,7 @@ class KeystoneEndpointTest(common.HeatTestCase):
         # Mock client
         self.keystoneclient = mock.Mock()
         self.patchobject(resource.Resource, 'client',
-                         return_value=fakes.FakeKeystoneClient(
+                         return_value=fake_ks.FakeKeystoneClient(
                              client=self.keystoneclient))
         self.endpoints = self.keystoneclient.endpoints
 
