@@ -14,12 +14,12 @@
 import mock
 from six.moves.urllib import parse
 
+from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
 from heat.engine import resource
 from heat.engine.resources.openstack.keystone import region
 from heat.engine import stack
 from heat.engine import template
 from heat.tests import common
-from heat.tests import fakes
 from heat.tests import utils
 
 KEYSTONE_REGION_TEMPLATE = {
@@ -37,8 +37,6 @@ KEYSTONE_REGION_TEMPLATE = {
     }
 }
 
-RESOURCE_TYPE = 'OS::Keystone::Region'
-
 
 class KeystoneRegionTest(common.HeatTestCase):
     def setUp(self):
@@ -56,7 +54,7 @@ class KeystoneRegionTest(common.HeatTestCase):
         # Mock client
         self.keystoneclient = mock.Mock()
         self.patchobject(resource.Resource, 'client',
-                         return_value=fakes.FakeKeystoneClient(
+                         return_value=fake_ks.FakeKeystoneClient(
                              client=self.keystoneclient))
         self.regions = self.keystoneclient.regions
 
