@@ -46,6 +46,7 @@ class PoolMemberTest(common.HeatTestCase):
             mock.MagicMock(return_value='123'))
         self.member.client_plugin().client = mock.MagicMock(
             return_value=self.neutron_client)
+        self.member.translate_properties(self.member.properties)
 
     def test_create(self):
         self._create_stack()
@@ -79,48 +80,6 @@ class PoolMemberTest(common.HeatTestCase):
         self.assertFalse(self.member.check_create_complete(props))
         self.assertTrue(self.member.check_create_complete(props))
 
-    def test_create_without_subnet(self):
-        tmpl = '''
-            heat_template_version: 2016-04-08
-            description: Create a pool member
-            resources:
-              member:
-                type: OS::Neutron::LBaaS::PoolMember
-                properties:
-                  pool: 123
-                  address: 1.2.3.4
-                  protocol_port: 80
-        '''
-        self._create_stack(tmpl=tmpl)
-        self.neutron_client.show_loadbalancer.side_effect = [
-            {'loadbalancer': {'provisioning_status': 'PENDING_UPDATE'}},
-            {'loadbalancer': {'provisioning_status': 'PENDING_UPDATE'}},
-            {'loadbalancer': {'provisioning_status': 'ACTIVE'}},
-        ]
-        self.neutron_client.create_lbaas_member.side_effect = [
-            exceptions.StateInvalidClient,
-            {'member': {'id': '1234'}}
-        ]
-        expected = {
-            'member': {
-                'address': '1.2.3.4',
-                'protocol_port': 80,
-                'weight': 1,
-                'admin_state_up': True,
-            }
-        }
-
-        props = self.member.handle_create()
-
-        self.assertFalse(self.member.check_create_complete(props))
-        self.neutron_client.create_lbaas_member.assert_called_with('123',
-                                                                   expected)
-        self.assertFalse(self.member.check_create_complete(props))
-        self.neutron_client.create_lbaas_member.assert_called_with('123',
-                                                                   expected)
-        self.assertFalse(self.member.check_create_complete(props))
-        self.assertTrue(self.member.check_create_complete(props))
-
     def test_show_resource(self):
         self._create_stack()
         self.member.resource_id_set('1234')
