@@ -16,6 +16,7 @@ import mock
 import six
 
 from oslo_config import cfg
+from zunclient import exceptions as zc_exc
 
 from heat.common import exception
 from heat.common import template_format
@@ -46,6 +47,16 @@ resources:
       restart_policy: on-failure:2
       interactive: false
       image_driver: docker
+      hints:
+        hintkey: hintval
+      hostname: myhost
+      security_groups:
+        - my_seg
+      mounts:
+        - volume_size: 1
+          mount_path: /data
+        - volume_id: 6ec29ba3-bf2c-4276-a88e-3670ea5abc80
+          mount_path: /data2
 '''
 
 
@@ -68,6 +79,18 @@ class ZunContainerTest(common.HeatTestCase):
                                     'Name': 'on-failure'}
         self.fake_interactive = False
         self.fake_image_driver = 'docker'
+        self.fake_hints = {'hintkey': 'hintval'}
+        self.fake_hostname = 'myhost'
+        self.fake_security_groups = ['my_seg']
+        self.fake_mounts = [
+            {'volume_id': None, 'volume_size': 1, 'mount_path': '/data'},
+            {'volume_id': '6ec29ba3-bf2c-4276-a88e-3670ea5abc80',
+             'volume_size': None, 'mount_path': '/data2'}]
+        self.fake_mounts_args = [
+            {'size': 1, 'destination': '/data'},
+            {'source': '6ec29ba3-bf2c-4276-a88e-3670ea5abc80',
+             'destination': '/data2'}]
+
         self.fake_network_id = '9c11d847-99ce-4a83-82da-9827362a68e8'
         self.fake_network_name = 'private'
         self.fake_networks = {
@@ -101,6 +124,7 @@ class ZunContainerTest(common.HeatTestCase):
         self.neutron_client = mock.Mock()
         self.patchobject(container.Container, 'neutron',
                          return_value=self.neutron_client)
+        self.stub_VolumeConstraint_validate()
 
     def _mock_get_client(self):
         value = mock.MagicMock()
@@ -116,6 +140,9 @@ class ZunContainerTest(common.HeatTestCase):
         value.restart_policy = self.fake_restart_policy
         value.interactive = self.fake_interactive
         value.image_driver = self.fake_image_driver
+        value.hints = self.fake_hints
+        value.hostname = self.fake_hostname
+        value.security_groups = self.fake_security_groups
         value.addresses = self.fake_addresses
         value.to_dict.return_value = value.__dict__
 
@@ -169,6 +196,18 @@ class ZunContainerTest(common.HeatTestCase):
         self.assertEqual(
             self.fake_image_driver,
             c.properties.get(container.Container.IMAGE_DRIVER))
+        self.assertEqual(
+            self.fake_hints,
+            c.properties.get(container.Container.HINTS))
+        self.assertEqual(
+            self.fake_hostname,
+            c.properties.get(container.Container.HOSTNAME))
+        self.assertEqual(
+            self.fake_security_groups,
+            c.properties.get(container.Container.SECURITY_GROUPS))
+        self.assertEqual(
+            self.fake_mounts,
+            c.properties.get(container.Container.MOUNTS))
 
         scheduler.TaskRunner(c.create)()
         self.assertEqual(self.resource_id, c.resource_id)
@@ -186,7 +225,11 @@ class ZunContainerTest(common.HeatTestCase):
             image_pull_policy=self.fake_image_policy,
             restart_policy=self.fake_restart_policy,
             interactive=self.fake_interactive,
-            image_driver=self.fake_image_driver
+            image_driver=self.fake_image_driver,
+            hints=self.fake_hints,
+            hostname=self.fake_hostname,
+            security_groups=self.fake_security_groups,
+            mounts=self.fake_mounts_args,
         )
 
     def test_container_create_failed(self):
@@ -229,9 +272,12 @@ class ZunContainerTest(common.HeatTestCase):
     def test_container_delete(self):
         c = self._create_resource('container', self.rsrc_defn, self.stack)
         scheduler.TaskRunner(c.create)()
+        self.patchobject(self.client.containers, 'get',
+                         side_effect=[c, zc_exc.NotFound('Not Found')])
         scheduler.TaskRunner(c.delete)()
         self.assertEqual((c.DELETE, c.COMPLETE), c.state)
-        self.assertEqual(1, self.client.containers.delete.call_count)
+        self.client.containers.delete.assert_called_once_with(
+            c.resource_id, stop=True)
 
     def test_container_delete_not_found(self):
         c = self._create_resource('container', self.rsrc_defn, self.stack)
@@ -240,7 +286,8 @@ class ZunContainerTest(common.HeatTestCase):
         self.client.containers.delete.side_effect = Exception('Not Found')
         scheduler.TaskRunner(c.delete)()
         self.assertEqual((c.DELETE, c.COMPLETE), c.state)
-        self.assertEqual(1, self.client.containers.delete.call_count)
+        self.client.containers.delete.assert_called_once_with(
+            c.resource_id, stop=True)
         mock_ignore_not_found = c.client_plugin.return_value.ignore_not_found
         self.assertEqual(1, mock_ignore_not_found.call_count)
 
