@@ -14,6 +14,7 @@
 import mock
 from oslo_utils import timeutils
 
+from heat.common import timeutils as heat_timeutils
 from heat.engine import notification
 from heat.tests import common
 from heat.tests import utils
@@ -36,7 +37,12 @@ class StackTest(common.HeatTestCase):
         st.created_time = created_time
         st.context = self.ctx
         st.id = 'hay-are-en'
-
+        updated_time = timeutils.utcnow()
+        st.updated_time = updated_time
+        st.tags = ['tag1', 'tag2']
+        st.t = mock.MagicMock()
+        st.t.__getitem__.return_value = 'for test'
+        st.t.DESCRIPTION = 'description'
         notify = self.patchobject(notification, 'notify')
 
         notification.stack.send(st)
@@ -49,8 +55,11 @@ class StackTest(common.HeatTestCase):
              'stack_identity': 'hay-are-en',
              'stack_name': 'fred',
              'tenant_id': 'test_tenant_id',
-             'create_at': created_time.isoformat(),
-             'state': 'x_f'})
+             'create_at': heat_timeutils.isotime(created_time),
+             'state': 'x_f',
+             'description': 'for test',
+             'tags': ['tag1', 'tag2'],
+             'updated_at': heat_timeutils.isotime(updated_time)})
 
 
 class AutoScaleTest(common.HeatTestCase):
@@ -58,7 +67,8 @@ class AutoScaleTest(common.HeatTestCase):
         super(AutoScaleTest, self).setUp()
         self.ctx = utils.dummy_context(user_id='test_user_id')
 
-    def test_send(self):
+    def _mock_stack(self):
+
         created_time = timeutils.utcnow()
         st = mock.Mock()
         st.state = ('x', 'f')
@@ -69,10 +79,20 @@ class AutoScaleTest(common.HeatTestCase):
         st.created_time = created_time
         st.context = self.ctx
         st.id = 'hay-are-en'
+        updated_time = timeutils.utcnow()
+        st.updated_time = updated_time
+        st.tags = ['tag1', 'tag2']
+        st.t = mock.MagicMock()
+        st.t.__getitem__.return_value = 'for test'
+        st.t.DESCRIPTION = 'description'
 
+        return st
+
+    def test_send(self):
+        stack = self._mock_stack()
         notify = self.patchobject(notification, 'notify')
 
-        notification.autoscaling.send(st, adjustment='x',
+        notification.autoscaling.send(stack, adjustment='x',
                                       adjustment_type='y',
                                       capacity='5',
                                       groupname='c',
@@ -87,26 +107,19 @@ class AutoScaleTest(common.HeatTestCase):
              'stack_identity': 'hay-are-en',
              'stack_name': 'fred',
              'tenant_id': 'test_tenant_id',
-             'create_at': created_time.isoformat(),
+             'create_at': heat_timeutils.isotime(stack.created_time),
+             'description': 'for test',
+             'tags': ['tag1', 'tag2'],
+             'updated_at': heat_timeutils.isotime(stack.updated_time),
              'state': 'x_f', 'adjustment_type': 'y',
              'groupname': 'c', 'capacity': '5',
              'message': 'fred', 'adjustment': 'x'})
 
     def test_send_error(self):
-        created_time = timeutils.utcnow()
-        st = mock.Mock()
-        st.state = ('x', 'f')
-        st.status = st.state[0]
-        st.action = st.state[1]
-        st.name = 'fred'
-        st.status_reason = 'this is why'
-        st.created_time = created_time
-        st.context = self.ctx
-        st.id = 'hay-are-en'
-
+        stack = self._mock_stack()
         notify = self.patchobject(notification, 'notify')
 
-        notification.autoscaling.send(st, adjustment='x',
+        notification.autoscaling.send(stack, adjustment='x',
                                       adjustment_type='y',
                                       capacity='5',
                                       groupname='c',
@@ -120,7 +133,10 @@ class AutoScaleTest(common.HeatTestCase):
              'stack_identity': 'hay-are-en',
              'stack_name': 'fred',
              'tenant_id': 'test_tenant_id',
-             'create_at': created_time.isoformat(),
+             'create_at': heat_timeutils.isotime(stack.created_time),
+             'description': 'for test',
+             'tags': ['tag1', 'tag2'],
+             'updated_at': heat_timeutils.isotime(stack.updated_time),
              'state': 'x_f', 'adjustment_type': 'y',
              'groupname': 'c', 'capacity': '5',
              'message': 'error', 'adjustment': 'x'})
