@@ -20,9 +20,11 @@ from heat.common import template_format
 from heat.db.sqlalchemy import api as db_api
 from heat.engine import environment
 from heat.engine import resource
+from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.engine import service
 from heat.engine import stack
+from heat.engine import support
 from heat.engine import template
 from heat.objects import stack as stack_object
 from heat.rpc import api as rpc_api
@@ -256,7 +258,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('xyz', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'xyz',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         loaded_stack = stack.Stack.load(self.ctx, self.stack.id)
         stored_props = loaded_stack['AResource']._stored_properties_data
@@ -394,8 +398,10 @@ class StackUpdateTest(common.HeatTestCase):
                                     template.Template(tmpl, env=env2))
 
         def check_and_raise(*args):
-            self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-            raise exception.UpdateReplace
+            self.assertEqual(
+                'abc',
+                self.stack['AResource']._stored_properties_data['Foo'])
+            raise resource.UpdateReplace
 
         mock_upd = self.patchobject(generic_rsrc.ResourceWithProps,
                                     'update_template_diff',
@@ -404,12 +410,16 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('xyz', self.stack['AResource'].properties['Foo'])
-        mock_upd.assert_called_once_with(
-            {'Type': 'ResourceWithPropsType',
-             'Properties': {'Foo': 'xyz'}},
-            {'Type': 'ResourceWithPropsType',
-             'Properties': {'Foo': 'abc'}})
+        self.assertEqual(
+            'xyz',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        after = rsrc_defn.ResourceDefinition('AResource',
+                                             'ResourceWithPropsType',
+                                             properties={'Foo': 'xyz'})
+        before = rsrc_defn.ResourceDefinition('AResource',
+                                              'ResourceWithPropsType',
+                                              properties={'Foo': 'abc'})
+        mock_upd.assert_called_once_with(after, before)
 
     def test_update_replace_create_hook(self):
         tmpl = {
@@ -445,7 +455,9 @@ class StackUpdateTest(common.HeatTestCase):
         # The hook is not called, and update succeeds properly
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('xyz', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'xyz',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
     def test_update_replace_delete_hook(self):
         tmpl = {
@@ -482,7 +494,9 @@ class StackUpdateTest(common.HeatTestCase):
         # The hook is not called, and update succeeds properly
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('xyz', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'xyz',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
     def test_update_replace_post_hook(self):
         tmpl = {
@@ -516,7 +530,9 @@ class StackUpdateTest(common.HeatTestCase):
         mock_hook.assert_called_once_with('post-update')
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual(2, self.stack['AResource'].properties['an_int'])
+        self.assertEqual(
+            '2',
+            self.stack['AResource']._stored_properties_data['an_int'])
 
     def test_update_modify_update_failed(self):
         tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
@@ -549,8 +565,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.FAILED),
                          self.stack.state)
         mock_upd.assert_called_once_with(
-            tmpl2['Resources']['AResource'],
-            {'Properties': {'Foo': 'xyz'}},
+            rsrc_defn.ResourceDefinition('AResource', 'ResourceWithPropsType',
+                                         properties={'Foo': 'xyz'}),
+            mock.ANY,
             {'Foo': 'xyz'})
 
     def test_update_modify_replace_failed_delete(self):
@@ -839,31 +856,36 @@ class StackUpdateTest(common.HeatTestCase):
                              cancel_message=rpc_api.THREAD_CANCEL):
         tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
                 'Resources': {'AResource': {'Type': 'GenericResourceType'}}}
-
+        old_tags = ['tag1', 'tag2']
         self.stack = stack.Stack(self.ctx, 'update_test_stack',
-                                 template.Template(tmpl))
+                                 template.Template(tmpl), tags=old_tags)
         self.stack.store()
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
+        self.assertEqual(old_tags, self.stack.tags)
 
         tmpl2 = {'HeatTemplateFormatVersion': '2012-12-12',
                  'Resources': {
                      'AResource': {'Type': 'GenericResourceType'},
-                     'BResource': {'Type': 'GenericResourceType'}}}
+                     'BResource': {'Type': 'MultiStepResourceType'}}}
+        new_tags = ['tag3', 'tag4']
         updated_stack = stack.Stack(self.ctx, 'updated_stack',
                                     template.Template(tmpl2),
-                                    disable_rollback=disable_rollback)
+                                    disable_rollback=disable_rollback,
+                                    tags=new_tags)
 
-        evt_mock = mock.MagicMock()
-        evt_mock.ready.return_value = True
-        evt_mock.wait.return_value = cancel_message
+        msgq_mock = mock.MagicMock()
+        msgq_mock.get_nowait.return_value = cancel_message
 
-        self.stack.update(updated_stack, event=evt_mock)
+        self.stack.update(updated_stack, msg_queue=msgq_mock)
 
         self.assertEqual(state, self.stack.state)
-        evt_mock.ready.assert_called_once_with()
-        evt_mock.wait.assert_called_once_with()
+        if disable_rollback:
+            self.assertEqual(new_tags, self.stack.tags)
+        else:
+            self.assertEqual(old_tags, self.stack.tags)
+        msgq_mock.get_nowait.assert_called_once_with()
 
     def test_update_force_cancel_no_rollback(self):
         self._update_force_cancel(
@@ -1024,9 +1046,11 @@ class StackUpdateTest(common.HeatTestCase):
                              self.stack.state)
             self.eng = service.EngineService('a-host', 'a-topic')
             events = self.eng.list_events(self.ctx, self.stack.identifier())
-            self.assertEqual(10, len(events))
+            self.assertEqual(11, len(events))
 
-            self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
+            self.assertEqual(
+                'abc',
+                self.stack['AResource']._stored_properties_data['Foo'])
             self.assertEqual(5, mock_db_update.call_count)
             self.assertEqual('UPDATE',
                              mock_db_update.call_args_list[0][0][2]['action'])
@@ -1060,16 +1084,16 @@ class StackUpdateTest(common.HeatTestCase):
         updated_stack = stack.Stack(self.ctx, 'updated_stack',
                                     template.Template(tmpl2),
                                     disable_rollback=False)
-        evt_mock = mock.MagicMock()
-        evt_mock.ready.return_value = True
-        evt_mock.wait.return_value = 'cancel'
+        msgq_mock = mock.MagicMock()
+        msgq_mock.get_nowait.return_value = 'cancel_with_rollback'
 
-        self.stack.update(updated_stack, event=evt_mock)
+        self.stack.update(updated_stack, msg_queue=msgq_mock)
         self.assertEqual((stack.Stack.ROLLBACK, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        evt_mock.ready.assert_called_once_with()
-        evt_mock.wait.assert_called_once_with()
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        msgq_mock.get_nowait.assert_called_once_with()
 
     def test_update_rollback_fail(self):
         tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
@@ -1245,31 +1269,29 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource',
-                         self.stack['BResource'].properties['Foo'])
-
-        self.ref_id_called = False
-
-        def get_ref_id(*args):
-            ref_id = 'inst-007' if self.ref_id_called else 'AResource'
-            if self.ref_id_called is False:
-                self.ref_id_called = True
-            return ref_id
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         mock_id = self.patchobject(generic_rsrc.ResourceWithProps,
-                                   'FnGetRefId',
-                                   side_effect=get_ref_id)
+                                   'get_reference_id',
+                                   return_value='inst-007')
 
         updated_stack = stack.Stack(self.ctx, 'updated_stack',
                                     template.Template(tmpl2))
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('inst-007', self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'inst-007',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
-        # Note: mock_id is called 14 times!!!
         mock_id.assert_called_with()
 
     def test_update_with_new_resources_with_reference(self):
@@ -1299,7 +1321,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['CResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['CResource']._stored_properties_data['Foo'])
         self.assertEqual(1, len(self.stack.resources))
 
         mock_create = self.patchobject(generic_rsrc.ResourceWithProps,
@@ -1310,9 +1334,12 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         self.assertEqual(3, len(self.stack.resources))
 
@@ -1346,12 +1373,16 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         mock_id = self.patchobject(generic_rsrc.ResourceWithProps,
-                                   'FnGetRefId', return_value='AResource')
+                                   'get_reference_id',
+                                   return_value='AResource')
 
         # mock to make the replace fail when creating the replacement resource
         mock_create = self.patchobject(generic_rsrc.ResourceWithProps,
@@ -1363,7 +1394,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.ROLLBACK, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         mock_id.assert_called_with()
         mock_create.assert_called_once_with()
@@ -1406,9 +1439,12 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource1',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource1',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         # mock to make the replace fail when creating the second
         # replacement resource
@@ -1421,9 +1457,12 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.ROLLBACK, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource1',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource1',
+            self.stack['BResource']._stored_properties_data['Foo'])
         mock_create.assert_called_once_with()
 
     def test_update_failure_recovery(self):
@@ -1468,9 +1507,12 @@ class StackUpdateTest(common.HeatTestCase):
 
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource1',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource1',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         # mock to make the replace fail when creating the second
         # replacement resource
@@ -1490,7 +1532,9 @@ class StackUpdateTest(common.HeatTestCase):
 
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.FAILED),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         self.stack = stack.Stack.load(self.ctx, self.stack.id)
         updated_stack2 = stack.Stack(self.ctx, 'updated_stack',
@@ -1501,9 +1545,12 @@ class StackUpdateTest(common.HeatTestCase):
 
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource2',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource2',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         self.assertEqual(2, mock_create.call_count)
         self.assertEqual(2, mock_delete.call_count)
@@ -1563,9 +1610,12 @@ class StackUpdateTest(common.HeatTestCase):
 
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource1',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource1',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         mock_create = self.patchobject(generic_rsrc.ResourceWithProps,
                                        'handle_create',
@@ -1583,7 +1633,9 @@ class StackUpdateTest(common.HeatTestCase):
         mock_create.assert_called_once_with()
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.FAILED),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         self.stack = stack.Stack.load(self.ctx, self.stack.id)
         updated_stack2 = stack.Stack(self.ctx, 'updated_stack',
@@ -1595,9 +1647,10 @@ class StackUpdateTest(common.HeatTestCase):
                          self.stack.state)
 
         self.stack = stack.Stack.load(self.ctx, self.stack.id)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource2',
-                         self.stack['BResource'].properties['Foo'])
+        a_props = self.stack['AResource']._stored_properties_data['Foo']
+        self.assertEqual('smelly', a_props)
+        b_props = self.stack['BResource']._stored_properties_data['Foo']
+        self.assertEqual('AResource2', b_props)
 
         self.assertEqual(2, mock_delete.call_count)
         mock_delete_A.assert_called_once_with()
@@ -1657,9 +1710,12 @@ class StackUpdateTest(common.HeatTestCase):
 
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource1',
-                         self.stack['BResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
+        self.assertEqual(
+            'AResource1',
+            self.stack['BResource']._stored_properties_data['Foo'])
 
         mock_create = self.patchobject(generic_rsrc.ResourceWithProps,
                                        'handle_create',
@@ -1677,7 +1733,9 @@ class StackUpdateTest(common.HeatTestCase):
         mock_create.assert_called_once_with()
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.FAILED),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         # check if heat stack-list works, wherein it tries to fetch template
         # parameters value from env
@@ -1695,9 +1753,10 @@ class StackUpdateTest(common.HeatTestCase):
                          self.stack.state)
 
         self.stack = stack.Stack.load(self.ctx, self.stack.id)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
-        self.assertEqual('AResource2',
-                         self.stack['BResource'].properties['Foo'])
+        a_props = self.stack['AResource']._stored_properties_data['Foo']
+        self.assertEqual('smelly', a_props)
+        b_props = self.stack['BResource']._stored_properties_data['Foo']
+        self.assertEqual('AResource2', b_props)
 
         self.assertEqual(2, mock_delete.call_count)
         mock_delete_A.assert_called_once_with()
@@ -1724,14 +1783,18 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         updated_stack = stack.Stack(self.ctx, 'updated_stack',
                                     template.Template(tmpl, env=env2))
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('smelly', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'smelly',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
     def test_update_deletion_policy(self):
         tmpl = {'HeatTemplateFormatVersion': '2012-12-12',
@@ -1811,7 +1874,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.create()
         self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('abc', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'abc',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
         tmpl2 = {
             'heat_template_version': '2013-05-23',
@@ -1831,7 +1896,9 @@ class StackUpdateTest(common.HeatTestCase):
         self.stack.update(updated_stack)
         self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
                          self.stack.state)
-        self.assertEqual('foo', self.stack['AResource'].properties['Foo'])
+        self.assertEqual(
+            'foo',
+            self.stack['AResource']._stored_properties_data['Foo'])
 
     def test_delete_stack_when_update_failed_twice(self):
         """Test when stack update failed twice and delete the stack.
@@ -1979,3 +2046,123 @@ class StackUpdateTest(common.HeatTestCase):
         # Bres in backup stack should have empty data.
         self.assertEqual({}, backup['Bres'].data())
         self.assertEqual({'test': '42'}, self.stack['Bres'].data())
+
+    def test_update_failed_with_new_condition(self):
+        create_a_res = {'equals': [{'get_param': 'create_a_res'}, 'yes']}
+        create_b_res = {'equals': [{'get_param': 'create_b_res'}, 'yes']}
+        tmpl = {
+            'heat_template_version': '2016-10-14',
+            'parameters': {
+                'create_a_res': {
+                    'type': 'string',
+                    'default': 'yes'
+                }
+            },
+            'conditions': {
+                'create_a': create_a_res
+            },
+            'resources': {
+                'Ares': {'type': 'GenericResourceType',
+                         'condition': 'create_a'}
+            }
+        }
+
+        test_stack = stack.Stack(self.ctx,
+                                 'test_update_failed_with_new_condition',
+                                 template.Template(tmpl))
+        test_stack.store()
+        test_stack.create()
+        self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
+                         test_stack.state)
+        self.assertIn('Ares', test_stack)
+
+        update_tmpl = copy.deepcopy(tmpl)
+        update_tmpl['conditions']['create_b'] = create_b_res
+        update_tmpl['parameters']['create_b_res'] = {
+            'type': 'string',
+            'default': 'yes'
+        }
+        update_tmpl['resources']['Bres'] = {
+            'type': 'OS::Heat::TestResource',
+            'properties': {
+                'value': 'res_b',
+                'fail': True
+            }
+        }
+
+        stack_with_new_resource = stack.Stack(
+            self.ctx,
+            'test_update_with_new_res_cd',
+            template.Template(update_tmpl))
+        test_stack.update(stack_with_new_resource)
+        self.assertEqual((stack.Stack.UPDATE, stack.Stack.FAILED),
+                         test_stack.state)
+        self.assertIn('Bres', test_stack)
+        self.assertEqual((resource.Resource.CREATE, resource.Resource.FAILED),
+                         test_stack['Bres'].state)
+        self.assertIn('create_b', test_stack.t.t['conditions'])
+        self.assertIn('create_b_res', test_stack.t.t['parameters'])
+
+    def test_stack_update_with_deprecated_resource(self):
+        """Test with update deprecated resource to substitute.
+
+        Test checks the following scenario:
+        1. Create stack with deprecated resource.
+        2. Update stack with substitute resource.
+        The test checks that deprecated resource can be update to it's
+        substitute resource during update Stack.
+        """
+
+        class ResourceTypeB(generic_rsrc.GenericResource):
+            count_b = 0
+
+            def update(self, after, before=None, prev_resource=None):
+                ResourceTypeB.count_b += 1
+
+        resource._register_class('ResourceTypeB', ResourceTypeB)
+
+        class ResourceTypeA(ResourceTypeB):
+            support_status = support.SupportStatus(
+                status=support.DEPRECATED,
+                message='deprecation_msg',
+                version='2014.2',
+                substitute_class=ResourceTypeB)
+
+            count_a = 0
+
+            def update(self, after, before=None, prev_resource=None):
+                ResourceTypeA.count_a += 1
+
+        resource._register_class('ResourceTypeA', ResourceTypeA)
+
+        TMPL_WITH_DEPRECATED_RES = """
+        heat_template_version: 2015-10-15
+        resources:
+          AResource:
+            type: ResourceTypeA
+        """
+        TMPL_WITH_PEPLACE_RES = """
+        heat_template_version: 2015-10-15
+        resources:
+          AResource:
+            type: ResourceTypeB
+        """
+        t = template_format.parse(TMPL_WITH_DEPRECATED_RES)
+        templ = template.Template(t)
+        self.stack = stack.Stack(self.ctx, 'update_test_stack',
+                                 templ)
+
+        self.stack.store()
+        self.stack.create()
+        self.assertEqual((stack.Stack.CREATE, stack.Stack.COMPLETE),
+                         self.stack.state)
+        t = template_format.parse(TMPL_WITH_PEPLACE_RES)
+        tmpl2 = template.Template(t)
+        updated_stack = stack.Stack(self.ctx, 'updated_stack',
+                                    tmpl2)
+        self.stack.update(updated_stack)
+        self.assertEqual((stack.Stack.UPDATE, stack.Stack.COMPLETE),
+                         self.stack.state)
+        self.assertIn('AResource', self.stack)
+        self.assertEqual(1, ResourceTypeB.count_b)
+        self.assertEqual(0, ResourceTypeA.count_a)
