@@ -31,7 +31,6 @@ echo -e 'logging_exception_prefix=%(asctime)s.%(msecs)03d %(process)d TRACE %(na
 
 echo -e '[heat_api]\nworkers=2\n' >> $localconf
 echo -e '[heat_api_cfn]\nworkers=2\n' >> $localconf
-echo -e '[heat_api_cloudwatch]\nworkers=2\n' >> $localconf
 
 echo -e '[cache]\nenabled=True\n' >> $localconf
 
@@ -39,10 +38,6 @@ echo -e '[eventlet_opts]\nclient_socket_timeout=120\n' >> $localconf
 
 echo -e '[oslo_messaging_notifications]\ndriver=messagingv2\n' >> $localconf
 
-# Disable nova quota check.
-echo -e '[[post-config|$NOVA_CONF]]\n[DEFAULT]\n' >> $localconf
-echo -e 'quota_driver=nova.quota.NoopQuotaDriver\n' >> $localconf
-
 echo "[[local|localrc]]" >> $localconf
 
 # NOTE(mnaser): This will use the region local mirrors to avoid going out
@@ -54,7 +49,6 @@ else
 	echo "IMAGE_URLS+=https://download.fedoraproject.org/pub/fedora/linux/releases/27/CloudImages/x86_64/images/Fedora-Cloud-Base-27-1.6.x86_64.qcow2" >> $localconf
 fi
 
-echo "CEILOMETER_BACKEND=mysql" >> $localconf
 echo "CEILOMETER_PIPELINE_INTERVAL=60" >> $localconf
 echo "HEAT_ENABLE_ADOPT_ABANDON=True" >> $localconf
 # Use the lbaas v2 namespace driver for devstack integration testing since
