@@ -21,5 +21,5 @@ HEAT_PRIVATE_SUBNET_CIDR=10.0.5.0/24
 # create a heat specific private network (default 'private' network has ipv6 subnet)
 source $DEST/devstack/openrc demo demo
 openstack network create heat-net
-neutron subnet-create --name heat-subnet heat-net $HEAT_PRIVATE_SUBNET_CIDR
+openstack subnet create heat-subnet --network heat-net --subnet-range $HEAT_PRIVATE_SUBNET_CIDR
 openstack router add subnet router1 heat-subnet
