@@ -16,20 +16,20 @@
 """Sample plugin for Heat.
 
 For more Heat related benchmarks take a look here:
-http://github.com/openstack/rally/tree/master/rally/plugins/openstack/scenarios/heat
+https://git.openstack.org/cgit/openstack/rally/tree/rally/plugins/openstack/scenarios/heat
 
-About plugins: https://rally.readthedocs.org/en/latest/plugins.html
+About plugins: https://rally.readthedocs.io/en/latest/plugins/#rally-plugins
 
 Rally concepts https://wiki.openstack.org/wiki/Rally/Concepts
 """
 
 
-from rally.benchmark.scenarios import base
+from rally.plugins.openstack import scenario
 
 
-class HeatPlugin(base.Scenario):
+class HeatPlugin(scenario.OpenStackScenario):
 
-    @base.scenario(context={"cleanup": ["heat"]})
+    @scenario.configure(context={"cleanup": ["heat"]})
     def list_benchmark(self, container_format,
                             image_location, disk_format, **kwargs):
         """Get heatclient and do whatever."""
